# Luxsci::SecureSendApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

Method | HTTP request | Description
------------- | ------------- | -------------
[**change_secure_send_user_password**](SecureSendApi.md#change_secure_send_user_password) | **PUT** /account/{accountId}/pl/namespaces/{namespaceId}/users/{username}/password | 
[**create_or_update_secure_send_user**](SecureSendApi.md#create_or_update_secure_send_user) | **PUT** /account/{accountId}/pl/namespaces/{namespaceId}/users/{username} | 
[**get_secure_send_user_list**](SecureSendApi.md#get_secure_send_user_list) | **GET** /account/{accountId}/pl/namespaces/{namespaceId}/users | 
[**get_secure_send_user_single_sign_on_link**](SecureSendApi.md#get_secure_send_user_single_sign_on_link) | **GET** /account/{accountId}/pl/namespaces/{namespaceId}/users/{username}/password | 

# **change_secure_send_user_password**
> InlineResponse201 change_secure_send_user_password(account_idnamespace_idusername, opts)



You can do this with the User Update function, above. We provide a simple, direct method here as well. {{ACL: Account: SecureSend Namespaces - Manage}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::SecureSendApi.new
account_id = 'account_id_example' # String | 
namespace_id = 'namespace_id_example' # String | 
username = 'username_example' # String | 
opts = { 
  body: Luxsci::UsernamePasswordBody1.new # UsernamePasswordBody1 | 
}

begin
  result = api_instance.change_secure_send_user_password(account_idnamespace_idusername, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling SecureSendApi->change_secure_send_user_password: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **String**|  | 
 **namespace_id** | **String**|  | 
 **username** | **String**|  | 
 **body** | [**UsernamePasswordBody1**](UsernamePasswordBody1.md)|  | [optional] 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **create_or_update_secure_send_user**
> InlineResponse201 create_or_update_secure_send_user(account_idnamespace_idusername, opts)



Create a new SecureSend User in a specific NameSpace. This function also validates the user’s account so the user does not have to do anything (like checking a link in his/her email) to start using the account.  If an account already exists for the specified user, then this request will merely update the user’s account, changing any data passed through. The “username” must be the email address (which is also the login) of the user to be created or updated.  When updating a user, request parameters omitted will not be updated. {{ACL: Account: SecureSend Namespaces - Manage}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::SecureSendApi.new
account_id = 'account_id_example' # String | 
namespace_id = 'namespace_id_example' # String | 
username = 'username_example' # String | 
opts = { 
  body: Luxsci::UsersUsernameBody1.new # UsersUsernameBody1 | 
}

begin
  result = api_instance.create_or_update_secure_send_user(account_idnamespace_idusername, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling SecureSendApi->create_or_update_secure_send_user: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **String**|  | 
 **namespace_id** | **String**|  | 
 **username** | **String**|  | 
 **body** | [**UsersUsernameBody1**](UsersUsernameBody1.md)|  | [optional] 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **get_secure_send_user_list**
> InlineResponse20073 get_secure_send_user_list(account_id, namespace_id, opts)



Return a list of all users in this NameSpace. {{ACL: Account: SecureSend Namespaces - Manage}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::SecureSendApi.new
account_id = 'account_id_example' # String | 
namespace_id = 'namespace_id_example' # String | 
opts = { 
}

begin
  result = api_instance.get_secure_send_user_list(account_id, namespace_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling SecureSendApi->get_secure_send_user_list: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **String**|  | 
 **namespace_id** | **String**|  | 

### Return type

[**InlineResponse20073**](InlineResponse20073.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **get_secure_send_user_single_sign_on_link**
> InlineResponse20072 get_secure_send_user_single_sign_on_link(account_id, namespace_id, username, opts)



Create a URL that the user can click on which will automatically log the user into the SecureSend Interface without needing to enter his/her username and password. For example, if the user has already authenticated him/herself in your system, you can use this API call to get a link that can be presented to the user so the user can then access SecureSend without needing to login again (e.g. “single sign-on”).  Note 1. This API call returns a URL. You can have the user click on that URL or you can redirect him/her to it. 2. This URL is valid for 15 minutes from the time of issuance. It can be used multiple times while it is in use. 3. These URLs are invalidated if the user’s password is changed. 4. These URLs will only work for someone coming from the IP address that your specified in your request for the URL. 5. All logins via Single Sign-on are logged in the user’s History and are denoted as Single Sign-on logins therein.   {{ACL: Account: SecureSend Single Sign-On}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::SecureSendApi.new
account_id = 'account_id_example' # String | 
namespace_id = 'namespace_id_example' # String | 
username = 'username_example' # String | 
opts = { 
  ip: 'ip_example', # String | The public IP address that the user is currently using. The resulting URL will only work for people accessing it from this IP.
  theme: 56, # Integer | The numerical Private Labeled Theme ID that this link should be generated for. You can find these IDs in your theme management area.<br><br>Not that the SecureSend NameSpace specified must be associated with this Theme, or the API will return an error.
}

begin
  result = api_instance.get_secure_send_user_single_sign_on_link(account_id, namespace_id, username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling SecureSendApi->get_secure_send_user_single_sign_on_link: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **String**|  | 
 **namespace_id** | **String**|  | 
 **username** | **String**|  | 
 **ip** | **String**| The public IP address that the user is currently using. The resulting URL will only work for people accessing it from this IP. | [optional] 
 **theme** | **Integer**| The numerical Private Labeled Theme ID that this link should be generated for. You can find these IDs in your theme management area.&lt;br&gt;&lt;br&gt;Not that the SecureSend NameSpace specified must be associated with this Theme, or the API will return an error. | [optional] 

### Return type

[**InlineResponse20072**](InlineResponse20072.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



