# luxsci

Luxsci - the Ruby gem for the LUXSCI

For a technical overview, see [LuxSci API Mechanics Guide](/rest-api/mechanics.html)  Return to [The API Guide](/rest-api.html)

This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: v2024.4.1
- Package version: 2024.4.1
- Build package: io.swagger.codegen.v3.generators.ruby.RubyClientCodegen

## Installation

Intall the gem found in this directory locally

```shell
gem install ./luxsci-2024.4.1.gem
```
(for development, run `gem install --dev ./luxsci-2024.4.1.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'luxsci', '~> 2024.4.1'


### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Authentication
The SDK's configurations must be set to handle authentication
```ruby
require 'luxsci'

Luxsci.configure do |config|
  config.private_token = "SECRET_TOKEN" # required
  config.public_token = "PUBLIC_TOKEN" # required
  # config.username = "USER" # optional. If you are authenticating into "user" scope with an explicit username and password, include the login email address of the user in question. E.g. "joe@domain.com"
  # config.password = "PASSWORD" # optional. If you are authenticating into "user" scope with an explicit username and password, include the plain text password for the user.
end
```
If configurations marked required are not present, the SDK will not proceed.

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:
```ruby
# Load the gem
require 'luxsci'
Luxsci.configure do |config|
  config.private_token = 'SECRET_TOKEN'
  config.public_token = 'PUBLIC_TOKEN'
end


api_instance = Luxsci::AuthenticationApi.new
opts = { 
  body: Luxsci::AuthBody.new # AuthBody | 
}

begin
  result = api_instance.authentication(opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling AuthenticationApi->authentication: #{e}"
end

api_instance = Luxsci::AuthenticationApi.new


begin
  result = api_instance.revoke_authentication()
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling AuthenticationApi->revoke_authentication: #{e}"
end

api_instance = Luxsci::ContentLibraryApi.new
username = 'username_example' # String | 
directory = 'directory_example' # String | Starting with the / following /content_library, this is the directory in {username} to create. This directory must not exist and, if it is a subdirectory, the parent directories must all exist.
opts = { 
}

begin
  result = api_instance.create_content_library_directory(username, directory, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling ContentLibraryApi->create_content_library_directory: #{e}"
end

api_instance = Luxsci::ContentLibraryApi.new
username = 'username_example' # String | 
directory = 'directory_example' # String | Starting with the / following /content_library, this is the directory in {username} to create. This directory must not exist and, if it is a subdirectory, the parent directories must all exist.
opts = { 
}

begin
  result = api_instance.delete_content_library_directory(username, directory, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling ContentLibraryApi->delete_content_library_directory: #{e}"
end

api_instance = Luxsci::ContentLibraryApi.new
username = 'username_example' # String | 
file_path = 'file_path_example' # String | Required. Starting with the / following /content_library, this is the path of the file in {username} to delete.  The path must not end in a training slash. Be sure to not use double slashes.  Example: \"/files/media/image.jpg\".
opts = { 
}

begin
  result = api_instance.delete_content_library_file(username, file_path, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling ContentLibraryApi->delete_content_library_file: #{e}"
end

api_instance = Luxsci::ContentLibraryApi.new
username = 'username_example' # String | 
directory = 'directory_example' # String | Starting with the / following /content_library, this is the directory in {username} to examine.  The path must end in a training slash. Be sure to not use double slashes.  Note, for example, that for directory \"/files/media/\" you would insert \"files/media/\" in this variable. If this value is omitted, the contents of the top-level directory will be returned.
opts = { 
}

begin
  result = api_instance.get_content_library_directory(username, directory, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling ContentLibraryApi->get_content_library_directory: #{e}"
end

api_instance = Luxsci::ContentLibraryApi.new
username = 'username_example' # String | 
file_path = 'file_path_example' # String | Required. Starting with the / following /content_library, this is the path of the file in {username}.  The path must not end in a training slash. Be sure to not use double slashes.  Example: \"/files/media/image.jpg\".
opts = { 
}

begin
  result = api_instance.get_content_library_file(username, file_path, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling ContentLibraryApi->get_content_library_file: #{e}"
end

api_instance = Luxsci::ContentLibraryApi.new
username = 'username_example' # String | 
file_path = 'file_path_example' # String | Required. Starting with the / following /content_library, this is the path in {username} to place the file.  The path must not end in a training slash. Be sure to not use double slashes. Example: \"files/media/image.jpg\".
opts = { 
  body: Luxsci::ContentLibraryFilePathBody.new, # ContentLibraryFilePathBody | 
}

begin
  result = api_instance.upload_content_library_file(username, file_path, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling ContentLibraryApi->upload_content_library_file: #{e}"
end

api_instance = Luxsci::DomainsApi.new
account_id = 'account_id_example' # String | 
opts = { 
  body: Luxsci::AccountIdDomainsBody.new, # AccountIdDomainsBody | 
}

begin
  result = api_instance.create_domain(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling DomainsApi->create_domain: #{e}"
end

api_instance = Luxsci::DomainsApi.new
account_id = 'account_id_example' # String | 
domain_name = 'domain_name_example' # String | 
opts = { 
}

begin
  result = api_instance.delete_domain(account_id, domain_name, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling DomainsApi->delete_domain: #{e}"
end

api_instance = Luxsci::DomainsApi.new
account_id = 'account_id_example' # String | 
domain_name = 'domain_name_example' # String | 
opts = { 
}

begin
  result = api_instance.get_domain_details(account_id, domain_name, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling DomainsApi->get_domain_details: #{e}"
end

api_instance = Luxsci::DomainsApi.new
account_id = 'account_id_example' # String | 
opts = { 
}

begin
  result = api_instance.get_domains_report(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling DomainsApi->get_domains_report: #{e}"
end

api_instance = Luxsci::DomainsApi.new
account_id = 'account_id_example' # String | 
domain_name = 'domain_name_example' # String | 
opts = { 
  body: Luxsci::DomainsDomainNameBody.new, # DomainsDomainNameBody | 
}

begin
  result = api_instance.update_domain(account_id, domain_name, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling DomainsApi->update_domain: #{e}"
end

api_instance = Luxsci::EmailApi.new
account_id = 'account_id_example' # String | 
opts = { 
  body: Luxsci::AccountIdBounceDomainBody.new, # AccountIdBounceDomainBody | 
}

begin
  api_instance.create_custom_bounce_domain(account_id, opts)
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailApi->create_custom_bounce_domain: #{e}"
end

api_instance = Luxsci::EmailApi.new
account_id = 'account_id_example' # String | 
opts = { 
  body: Luxsci::AccountIdDkimBody.new, # AccountIdDkimBody | 
}

begin
  api_instance.create_dkim(account_id, opts)
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailApi->create_dkim: #{e}"
end

api_instance = Luxsci::EmailApi.new
account_id = 'account_id_example' # String | 
domain_name = 'domain_name_example' # String | 
opts = { 
}

begin
  result = api_instance.delete_dkim(account_id, domain_name, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailApi->delete_dkim: #{e}"
end

api_instance = Luxsci::EmailApi.new
username = 'username_example' # String | 
id = 'id_example' # String | 
opts = { 
}

begin
  result = api_instance.delete_email_auto_responder(username, id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailApi->delete_email_auto_responder: #{e}"
end

api_instance = Luxsci::EmailApi.new
account_id = 'account_id_example' # String | 
domain_name = 'domain_name_example' # String | 
opts = { 
}

begin
  result = api_instance.get_dkim_details(account_id, domain_name, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailApi->get_dkim_details: #{e}"
end

api_instance = Luxsci::EmailApi.new
account_id = 'account_id_example' # String | 
opts = { 
}

begin
  result = api_instance.get_dkim_report(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailApi->get_dkim_report: #{e}"
end

api_instance = Luxsci::EmailApi.new
username = 'username_example' # String | 
opts = { 
}

begin
  result = api_instance.get_email_auto_responders(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailApi->get_email_auto_responders: #{e}"
end

api_instance = Luxsci::EmailApi.new
username = 'username_example' # String | 
opts = { 
  body: Luxsci::EmailArBody.new # EmailArBody | 
}

begin
  result = api_instance.new_email_auto_responder(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailApi->new_email_auto_responder: #{e}"
end

api_instance = Luxsci::EmailApi.new
username = 'username_example' # String | 
opts = { 
  body: Luxsci::SecurelineRecipientsBody.new, # SecurelineRecipientsBody | 
}

begin
  result = api_instance.retrieve_secure_line_recipient_list_encryption_data(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailApi->retrieve_secure_line_recipient_list_encryption_data: #{e}"
end

api_instance = Luxsci::EmailApi.new
username = 'username_example' # String | 
opts = { 
  body: Luxsci::EmailForwardingBody.new, # EmailForwardingBody | 
}

begin
  result = api_instance.update_email_forwarding(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailApi->update_email_forwarding: #{e}"
end

api_instance = Luxsci::EmailAliasesApi.new
account_id = 'account_id_example' # String | 
opts = { 
  body: Luxsci::AccountIdAliasesBody.new, # AccountIdAliasesBody | The Request body contains the following settings for new email aliases. While you can add multiple aliases at once, you should not have duplicates in your list.
}

begin
  result = api_instance.create_alias(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailAliasesApi->create_alias: #{e}"
end

api_instance = Luxsci::EmailAliasesApi.new
account_id = 'account_id_example' # String | 
alias_address = 'alias_address_example' # String | 
opts = { 
}

begin
  result = api_instance.delete_alias(account_id, alias_address, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailAliasesApi->delete_alias: #{e}"
end

api_instance = Luxsci::EmailAliasesApi.new
account_id = 'account_id_example' # String | 
alias_address = 'alias_address_example' # String | 
opts = { 
}

begin
  result = api_instance.get_alias_details(account_id, alias_address, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailAliasesApi->get_alias_details: #{e}"
end

api_instance = Luxsci::EmailAliasesApi.new
account_id = 'account_id_example' # String | 
opts = { 
}

begin
  result = api_instance.get_aliases_report(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailAliasesApi->get_aliases_report: #{e}"
end

api_instance = Luxsci::EmailAliasesApi.new
account_id = 'account_id_example' # String | 
alias_address = 'alias_address_example' # String | 
opts = { 
  body: Luxsci::AliasesAliasAddressBody.new, # AliasesAliasAddressBody | The Request body contains the following settings for updating an email alias.
}

begin
  result = api_instance.update_alias(account_id, alias_address, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailAliasesApi->update_alias: #{e}"
end

api_instance = Luxsci::EmailSendingApi.new
account_id = 56 # Integer | 
opts = { 
  body: Luxsci::Suppression.new, # Suppression | 
}

begin
  result = api_instance.create_account_suppression(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->create_account_suppression: #{e}"
end

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
opts = { 
  body: Luxsci::UsernameFieldsBody.new, # UsernameFieldsBody | 
}

begin
  result = api_instance.create_custom_field(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->create_custom_field: #{e}"
end

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
opts = { 
  body: Luxsci::ContentTag.new, # ContentTag | 
}

begin
  result = api_instance.create_email_content_tag(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->create_email_content_tag: #{e}"
end

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
opts = { 
  body: Luxsci::Template.new, # Template | 
}

begin
  result = api_instance.create_email_template(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->create_email_template: #{e}"
end

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
opts = { 
  body: Luxsci::TemplateGroupTemplateGroupIdBody.new, # TemplateGroupTemplateGroupIdBody | 
}

begin
  result = api_instance.create_email_template_group(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->create_email_template_group: #{e}"
end

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
opts = { 
  body: Luxsci::Suppression.new, # Suppression | 
}

begin
  result = api_instance.create_user_suppression(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->create_user_suppression: #{e}"
end

api_instance = Luxsci::EmailSendingApi.new
account_id = 'account_id_example' # String | 
email = 'email_example' # String | Suppression email address to be deleted.
opts = { 
}

begin
  result = api_instance.delete_account_suppression(account_id, email, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->delete_account_suppression: #{e}"
end

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
tag_id = 'tag_id_example' # String | tag_id can be either the unique numerical tag_id or the text code_word
opts = { 
}

begin
  result = api_instance.delete_email_content_tag(username, tag_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->delete_email_content_tag: #{e}"
end

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
template_id = 'template_id_example' # String | template_id can be either the unique numerical template_id or the text code_word
opts = { 
}

begin
  result = api_instance.delete_email_template(username, template_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->delete_email_template: #{e}"
end

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
template_group_id = 'template_group_id_example' # String | Unique Id for this template group.
opts = { 
}

begin
  result = api_instance.delete_email_template_group(username, template_group_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->delete_email_template_group: #{e}"
end

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
email = 'email_example' # String | Suppression email address to be deleted.
opts = { 
}

begin
  result = api_instance.delete_user_suppression(username, email, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->delete_user_suppression: #{e}"
end

api_instance = Luxsci::EmailSendingApi.new
account_id = 56 # Integer | 
email = 'email_example' # String | Suppression email address to be retrieved. You are returning all suppression entries that contain the string 'email'.  Note that even if you specify a full email address for 'email,' you can get multiple matches.
opts = { 
}

begin
  result = api_instance.get_account_suppression(account_id, email, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->get_account_suppression: #{e}"
end

api_instance = Luxsci::EmailSendingApi.new
account_id = 'account_id_example' # String | 
opts = { 
}

begin
  result = api_instance.get_account_suppression_list(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->get_account_suppression_list: #{e}"
end

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
opts = { 
}

begin
  result = api_instance.get_custom_fields(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->get_custom_fields: #{e}"
end

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
domain = 'domain_example' # String | 
opts = { 
}

begin
  result = api_instance.get_domain_smtp_tls_capability(username, domain, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->get_domain_smtp_tls_capability: #{e}"
end

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
tag_id = 'tag_id_example' # String | can either be the numerical unique ID of the Cotent Tag, or its 'code_word'
opts = { 
}

begin
  result = api_instance.get_email_content_tag(username, tag_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->get_email_content_tag: #{e}"
end

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
opts = { 
}

begin
  result = api_instance.get_email_content_tag_list(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->get_email_content_tag_list: #{e}"
end

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
template_id = 'template_id_example' # String | can either be the numerical unique ID of the template, or the textual “code_word”
opts = { 
}

begin
  result = api_instance.get_email_template(username, template_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->get_email_template: #{e}"
end

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
opts = { 
}

begin
  result = api_instance.get_email_template_groups(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->get_email_template_groups: #{e}"
end

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
opts = { 
  user_id: 56, # Integer | Restricts the templates returned to only those owned by a specific user, [user_id].  This is relevent when [username] used belongs to a Team. In that case, all non-private Templates of all Team members are returned by this call unless this parameter is specified.
}

begin
  result = api_instance.get_email_template_list(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->get_email_template_list: #{e}"
end

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
email = 'email_example' # String | Suppression email address to be retrieved. You are returning all suppression entries that contain the string 'email'.  Note that even if you specify a full email address for 'email,' you can get multiple matches.
opts = { 
}

begin
  result = api_instance.get_user_suppression(username, email, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->get_user_suppression: #{e}"
end

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
opts = { 
}

begin
  result = api_instance.get_user_suppression_list(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->get_user_suppression_list: #{e}"
end

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
opts = { 
  body: Luxsci::EmailSendBody.new, # EmailSendBody | 
  json: Luxsci::UserusernameemailsendJson.new, # UserusernameemailsendJson | 
  files: ['files_example'], # Array<String> | 
}

begin
  result = api_instance.send_email(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->send_email: #{e}"
end

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
opts = { 
  body: Luxsci::SecurelineSendBody.new, # SecurelineSendBody | 
}

begin
  result = api_instance.send_secure_email_or_secure_text(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->send_secure_email_or_secure_text: #{e}"
end

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
tag_id = 'tag_id_example' # String | tag_id can be either the unique numerical tag_id or the code_word.
opts = { 
  body: Luxsci::ContentTag.new, # ContentTag | 
}

begin
  result = api_instance.update_email_content_tag(username, tag_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->update_email_content_tag: #{e}"
end

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
template_id = 'template_id_example' # String | template_id can be either the unique numerical template_id or the text code_word.
opts = { 
  body: Luxsci::Template.new, # Template | 
}

begin
  result = api_instance.update_email_template(username, template_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->update_email_template: #{e}"
end

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
template_group_id = 'template_group_id_example' # String | Unique Id for this template group.
opts = { 
  body: Luxsci::TemplateGroupTemplateGroupIdBody1.new, # TemplateGroupTemplateGroupIdBody1 | 
}

begin
  result = api_instance.update_email_template_group(username, template_group_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->update_email_template_group: #{e}"
end

api_instance = Luxsci::MarketingApi.new
account_id = 'account_id_example' # String | 
opts = { 
  body: Luxsci::MarketingAddCampaignBody.new, # MarketingAddCampaignBody | 
}

begin
  result = api_instance.add_marketing_campaign(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling MarketingApi->add_marketing_campaign: #{e}"
end

api_instance = Luxsci::MarketingApi.new
account_id = 'account_id_example' # String | 
opts = { 
  body: Luxsci::MarketingAddContactBody.new, # MarketingAddContactBody | 
}

begin
  result = api_instance.add_marketing_contact(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling MarketingApi->add_marketing_contact: #{e}"
end

api_instance = Luxsci::MarketingApi.new
account_id = 'account_id_example' # String | 
opts = { 
  body: Luxsci::MarketingAddContactsBody.new, # MarketingAddContactsBody | 
}

begin
  result = api_instance.add_marketing_contacts(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling MarketingApi->add_marketing_contacts: #{e}"
end

api_instance = Luxsci::MarketingApi.new
account_id = 'account_id_example' # String | 
opts = { 
  body: Luxsci::MarketingAddListBody.new, # MarketingAddListBody | 
}

begin
  result = api_instance.add_marketing_list(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling MarketingApi->add_marketing_list: #{e}"
end

api_instance = Luxsci::MarketingApi.new
account_id = 'account_id_example' # String | 
opts = { 
  body: Luxsci::MarketingSuppressBody.new, # MarketingSuppressBody | 
}

begin
  result = api_instance.add_new_marketing_suppression(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling MarketingApi->add_new_marketing_suppression: #{e}"
end

api_instance = Luxsci::MarketingApi.new
account_id = 'account_id_example' # String | 
id = 56 # Integer | 
opts = { 
}

begin
  result = api_instance.delete_marketing_campaign(account_id, id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling MarketingApi->delete_marketing_campaign: #{e}"
end

api_instance = Luxsci::MarketingApi.new
account_id = 'account_id_example' # String | 
id = 56 # Integer | 
opts = { 
}

begin
  result = api_instance.delete_marketing_contact_by_id(account_id, id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling MarketingApi->delete_marketing_contact_by_id: #{e}"
end

api_instance = Luxsci::MarketingApi.new
account_id = 'account_id_example' # String | 
id = 'id_example' # String | List Id.
opts = { 
}

begin
  result = api_instance.delete_marketing_list(account_id, id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling MarketingApi->delete_marketing_list: #{e}"
end

api_instance = Luxsci::MarketingApi.new
account_id = 'account_id_example' # String | 
id = 'id_example' # String | List group Id.
opts = { 
}

begin
  result = api_instance.delete_marketing_list_group(account_id, id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling MarketingApi->delete_marketing_list_group: #{e}"
end

api_instance = Luxsci::MarketingApi.new
account_id = 'account_id_example' # String | 
type = 'type_example' # String | email, domain, ip Select type of suppression
opts = { 
  id: 56, # Integer | id of the suppressed entry
  reference: 'reference_example', # String | Select suppressed records according to this reference you want to delete
}

begin
  result = api_instance.delete_marketing_suppression(account_id, type, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling MarketingApi->delete_marketing_suppression: #{e}"
end

api_instance = Luxsci::MarketingApi.new
account_id = 'account_id_example' # String | 
schedule_id = 56 # Integer | Schedule id of schedule to get bounced stats
opts = { 
  limit_start: 0, # Integer | Starting row of result. Default: 0
  limit_count: 25, # Integer | Number of records to get. Default: 25
}

begin
  result = api_instance.get_marketing_campaign_bounced_statistics(account_id, schedule_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling MarketingApi->get_marketing_campaign_bounced_statistics: #{e}"
end

api_instance = Luxsci::MarketingApi.new
account_id = 'account_id_example' # String | 
schedule_id = 56 # Integer | Schedule id of schedule to get clicked stats
opts = { 
  limit_start: 0, # Integer | Starting row of result. Default: 0
  limit_count: 25, # Integer | Number of records to get. Default: 25
}

begin
  result = api_instance.get_marketing_campaign_clicked_statistics(account_id, schedule_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling MarketingApi->get_marketing_campaign_clicked_statistics: #{e}"
end

api_instance = Luxsci::MarketingApi.new
account_id = 'account_id_example' # String | 
opts = { 
  id: 56, # Integer | id of the campaign group to fetch details for.
  user_id: 56, # Integer | Get campaign groups of a particular user.
  limit_start: 0, # Integer | Starting row of result. Default: 0
  limit_count: 25 # Integer | Number of records to get. Default: 25
}

begin
  result = api_instance.get_marketing_campaign_groups(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling MarketingApi->get_marketing_campaign_groups: #{e}"
end

api_instance = Luxsci::MarketingApi.new
account_id = 'account_id_example' # String | 
schedule_id = 56 # Integer | Schedule id of schedule to get open stats
opts = { 
  limit_start: 0, # Integer | Starting row of result. Default: 0
  limit_count: 25, # Integer | Number of records to get. Default: 25
}

begin
  result = api_instance.get_marketing_campaign_opened_statistics(account_id, schedule_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling MarketingApi->get_marketing_campaign_opened_statistics: #{e}"
end

api_instance = Luxsci::MarketingApi.new
account_id = 'account_id_example' # String | 
schedule_id = 'schedule_id_example' # String | Schedule id of schedule to get its statatistics summary.
opts = { 
}

begin
  result = api_instance.get_marketing_campaign_statistics_summary(account_id, schedule_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling MarketingApi->get_marketing_campaign_statistics_summary: #{e}"
end

api_instance = Luxsci::MarketingApi.new
account_id = 'account_id_example' # String | 
schedule_id = 56 # Integer | Schedule id of schedule to get unsubscribe stats
opts = { 
  limit_start: 0, # Integer | Starting row of result. Default: 0
  limit_count: 25, # Integer | Number of records to get. Default: 25
}

begin
  result = api_instance.get_marketing_campaign_unsubscribed_statistics(account_id, schedule_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling MarketingApi->get_marketing_campaign_unsubscribed_statistics: #{e}"
end

api_instance = Luxsci::MarketingApi.new
account_id = 'account_id_example' # String | 
id = 56 # Integer | Use if you want to restrict details to specific Campaign id. If left blank, all your campaigns’ details will be returned.
group_id = 56 # Integer | Group id of the campaigns you want to get.
limit_start = 0 # Integer | Starting row of result. Default: 0
limit_count = 25 # Integer | Number of records to get. Default: 25
opts = { 
}

begin
  result = api_instance.get_marketing_campaigns(account_id, id, group_id, limit_start, limit_count, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling MarketingApi->get_marketing_campaigns: #{e}"
end

api_instance = Luxsci::MarketingApi.new
account_id = 'account_id_example' # String | 
id = 56 # Integer | 
opts = { 
  full_details: 56, # Integer | If specified and set to 1, add contact details will be returned, including the values of all additional fields.
}

begin
  result = api_instance.get_marketing_contact_by_id(account_id, id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling MarketingApi->get_marketing_contact_by_id: #{e}"
end

api_instance = Luxsci::MarketingApi.new
account_id = 'account_id_example' # String | 
list_id = 56 # Integer | Contact list id for the contacts you want to get.
limit_start = 0 # Integer | Starting row of result. Default: 0
limit_count = 25 # Integer | Number of records to get. Default: 25
opts = { 
  full_details: 56, # Integer | If specified and set to 1, add contact details will be returned, including the values of all additional fields.
}

begin
  result = api_instance.get_marketing_contacts(account_id, list_id, limit_start, limit_count, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling MarketingApi->get_marketing_contacts: #{e}"
end

api_instance = Luxsci::MarketingApi.new
account_id = 'account_id_example' # String | 
opts = { 
  id: 56, # Integer | id of the List Group to fetch details for.
  user_id: 56, # Integer | Get list groups of a particular user.
  limit_start: 0, # Integer | Starting row of result. Default: 0
  limit_count: 25 # Integer | Number of records to get. Default: 25
}

begin
  result = api_instance.get_marketing_list_groups(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling MarketingApi->get_marketing_list_groups: #{e}"
end

api_instance = Luxsci::MarketingApi.new
account_id = 'account_id_example' # String | 
opts = { 
  list_id: 56, # Integer | List id for the specific contact list you want details for.
  group_id: 56, # Integer | Group id for all getting lists in a specific group
}

begin
  result = api_instance.get_marketing_lists(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling MarketingApi->get_marketing_lists: #{e}"
end

api_instance = Luxsci::MarketingApi.new
account_id = 'account_id_example' # String | 
opts = { 
  id: 56, # Integer | id of the campaign to fetch details for.
  user_id: 56, # Integer | Get campaigns of a particular user.
  limit_start: 25, # Integer | Number of records to get. Default: 25.
  limit_count: 25, # Integer | Number of records to get. Default: 25.
  t_start: 56, # Integer | The start time from when to fetch the scheduled campaign. Supported format (dd-mm-yyyy_hh-mm-ss)
  t_end: 56 # Integer | The end time from when to fetch the scheduled campaign. Supported format (dd-mm-yyyy_hh-mm-ss)
}

begin
  result = api_instance.get_marketing_scheduled_campaigns(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling MarketingApi->get_marketing_scheduled_campaigns: #{e}"
end

api_instance = Luxsci::MarketingApi.new
account_id = 'account_id_example' # String | 
type = 'type_example' # String | email, domain, ip Select type of suppression list you want to get
opts = { 
  id: 56, # Integer | id of the suppressed entry
  reference: 'reference_example', # String | Get suppressed records according to this reference
  limit_start: 0, # Integer | Starting row of result. Default: 0
  limit_count: 25, # Integer | Number of records to get. Default: 25
}

begin
  result = api_instance.get_marketing_suppressions(account_id, type, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling MarketingApi->get_marketing_suppressions: #{e}"
end

api_instance = Luxsci::MarketingApi.new
account_id = 'account_id_example' # String | 
id = 'id_example' # String | 
opts = { 
}

begin
  result = api_instance.mark_contact_as_unsubscribed(account_id, id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling MarketingApi->mark_contact_as_unsubscribed: #{e}"
end

api_instance = Luxsci::MarketingApi.new
account_id = 'account_id_example' # String | 
opts = { 
  body: Luxsci::MarketingCampaignScheduleBody.new, # MarketingCampaignScheduleBody | 
}

begin
  result = api_instance.schedule_marketing_campaign(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling MarketingApi->schedule_marketing_campaign: #{e}"
end

api_instance = Luxsci::MarketingApi.new
account_id = 'account_id_example' # String | 
id = 'id_example' # String | 
opts = { 
  body: Luxsci::UpdateCampaignIdBody.new, # UpdateCampaignIdBody | 
}

begin
  result = api_instance.update_marketing_campaign(account_id, id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling MarketingApi->update_marketing_campaign: #{e}"
end

api_instance = Luxsci::MarketingApi.new
account_id = 'account_id_example' # String | 
email = 'email_example' # String | 
opts = { 
  body: Luxsci::UpdateContactEmailBody.new, # UpdateContactEmailBody | 
}

begin
  result = api_instance.update_marketing_contact_by_email(account_id, email, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling MarketingApi->update_marketing_contact_by_email: #{e}"
end

api_instance = Luxsci::MarketingApi.new
account_id = 'account_id_example' # String | 
id = 'id_example' # String | 
opts = { 
  body: Luxsci::UpdateContactRequestBody.new, # UpdateContactRequestBody | 
}

begin
  result = api_instance.update_marketing_contact_by_id(account_id, id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling MarketingApi->update_marketing_contact_by_id: #{e}"
end

api_instance = Luxsci::MarketingApi.new
account_id = 'account_id_example' # String | 
id = 'id_example' # String | List Id.
opts = { 
  body: Luxsci::UpdateListIdBody.new, # UpdateListIdBody | 
}

begin
  result = api_instance.update_marketing_list(account_id, id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling MarketingApi->update_marketing_list: #{e}"
end

api_instance = Luxsci::Marketing3Api.new
username = 'username_example' # String | 
opts = { 
  body: Luxsci::SM3CampaignPOSTBody.new, # SM3CampaignPOSTBody | 
}

begin
  result = api_instance.add_campaign(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling Marketing3Api->add_campaign: #{e}"
end

api_instance = Luxsci::Marketing3Api.new
username = 'username_example' # String | 
opts = { 
  body: nil, # Hash<String, String> | 
}

begin
  result = api_instance.add_contact(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling Marketing3Api->add_contact: #{e}"
end

api_instance = Luxsci::Marketing3Api.new
body = nil # Object | An array of JSON objects containing Contact properties.
username = 'username_example' # String | 
opts = { 
}

begin
  result = api_instance.add_contacts(body, username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling Marketing3Api->add_contacts: #{e}"
end

api_instance = Luxsci::Marketing3Api.new
body = Luxsci::SM3ListBody.new # SM3ListBody | A JSON object containing List properties.
username = 'username_example' # String | 
opts = { 
}

begin
  result = api_instance.add_list(body, username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling Marketing3Api->add_list: #{e}"
end

api_instance = Luxsci::Marketing3Api.new
username = 'username_example' # String | 
opts = { 
  body: Luxsci::ListGroupListGroupIdBody.new, # ListGroupListGroupIdBody | 
}

begin
  result = api_instance.add_list_group(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling Marketing3Api->add_list_group: #{e}"
end

api_instance = Luxsci::Marketing3Api.new
username = 'username_example' # String | 
campaign_id = 'campaign_id_example' # String | Campaign Id.
opts = { 
}

begin
  result = api_instance.delete_campaign(username, campaign_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling Marketing3Api->delete_campaign: #{e}"
end

api_instance = Luxsci::Marketing3Api.new
username = 'username_example' # String | 
contact_id = 'contact_id_example' # String | List Id.
opts = { 
}

begin
  result = api_instance.delete_contact(username, contact_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling Marketing3Api->delete_contact: #{e}"
end

api_instance = Luxsci::Marketing3Api.new
username = 'username_example' # String | 
id = 'id_example' # String | List Id.
opts = { 
  contacts_only: 56, # Integer | If passed and true, this call will delete all contacts in the list, but the list itself will not be deleted.
}

begin
  result = api_instance.delete_list(username, id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling Marketing3Api->delete_list: #{e}"
end

api_instance = Luxsci::Marketing3Api.new
username = 'username_example' # String | 
list_group_id = 'list_group_id_example' # String | Unique Id for this list group.
opts = { 
}

begin
  result = api_instance.delete_list_group(username, list_group_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling Marketing3Api->delete_list_group: #{e}"
end

api_instance = Luxsci::Marketing3Api.new
username = 'username_example' # String | 
campaign_id = 56 # Integer | Campaign id for the specific campaign you want details for.
opts = { 
}

begin
  result = api_instance.get_campaign(username, campaign_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling Marketing3Api->get_campaign: #{e}"
end

api_instance = Luxsci::Marketing3Api.new
username = 'username_example' # String | 
opts = { 
  user_id: 56, # Integer | Select campaigns owned by the given user ID.
  status: 'status_example', # String | Campaign Status Enum.
  use_date: 'created', # String | This report uses the Campaign created date by default for all date-related filtering and sorting.  Set this parameter to \"modified\" to instead used the modified date.  Set it to \"send_at\" to use the date/time that the Campaign is scheduled to be sent.  Any other value passed in this parameter will cause the \"created\" date to be used.
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example' # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
}

begin
  result = api_instance.get_campaigns(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling Marketing3Api->get_campaigns: #{e}"
end

api_instance = Luxsci::Marketing3Api.new
username = 'username_example' # String | 
contact_id = 56 # Integer | Contact id for the specific contact list you want details for.
opts = { 
  details: 56, # Integer | If details=1 (default) return custom fields.
}

begin
  result = api_instance.get_contact(username, contact_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling Marketing3Api->get_contact: #{e}"
end

api_instance = Luxsci::Marketing3Api.new
username = 'username_example' # String | 
opts = { 
  use_date: 'created', # String | This report uses the created date by default for all date-related filtering and sorting.  Set this parameter to \"modified\" to instead used the modified date. Any other value passed in this parameter will cause the \"created\" date to be used.
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  list_id: 56, # Integer | List id to get all contacts in a specific List. If this is omitted, then all contacts across all Lists will be returned.
  segment_id: 56, # Integer | Segment id to get all contacts in a specific Segment.  Note that you can specify both a segment_id and a list_id to get contacts in a specific List that are also in a specific Segment.
  details: 56, # Integer | Whe nset to true (1), data for all custom fields will also be included in the response.
}

begin
  result = api_instance.get_contacts(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling Marketing3Api->get_contacts: #{e}"
end

api_instance = Luxsci::Marketing3Api.new
username = 'username_example' # String | 
list_id = 56 # Integer | List id for the specific contact list you want details for.
opts = { 
}

begin
  result = api_instance.get_list(username, list_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling Marketing3Api->get_list: #{e}"
end

api_instance = Luxsci::Marketing3Api.new
username = 'username_example' # String | 
opts = { 
}

begin
  result = api_instance.get_list_groups(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling Marketing3Api->get_list_groups: #{e}"
end

api_instance = Luxsci::Marketing3Api.new
username = 'username_example' # String | 
opts = { 
  list_group_id: 56, # Integer | Group id getting all lists in a specific group
  use_date: 'created', # String | This report uses the created date by default for all date-related filtering and sorting.  Set this parameter to \"modified\" to instead used the modified date. Any other value passed in this parameter will cause the \"created\" date to be used.
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example' # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
}

begin
  result = api_instance.get_lists(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling Marketing3Api->get_lists: #{e}"
end

api_instance = Luxsci::Marketing3Api.new
username = 'username_example' # String | 
opts = { 
  campaign_ids: 'campaign_ids_example', # String | Select campaigns as string of comma-separated campaign ids.  If omitted, all campaigns are selected.
  detail: 'detail_example', # String | Boolean.  If 1, include the values of all Contact Custom Fields in the report. Default is 0.
  email: 'email_example', # String | Filter results by matching any Contact email address containing the given string.
  domain: 'domain_example', # String | Filter results by matching any Contact email address in a domain name containing the given string.
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example' # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
}

begin
  result = api_instance.get_report_bounced(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling Marketing3Api->get_report_bounced: #{e}"
end

api_instance = Luxsci::Marketing3Api.new
username = 'username_example' # String | 
opts = { 
  campaign_ids: 'campaign_ids_example', # String | Select campaigns as string of comma-separated campaign ids.  If omitted, all campaigns are selected.
  use_date: 'use_date_example', # String | If set to \"sent\", use the date the message was sent, instead of the date of the open event, for date selections.
  detail: 'detail_example', # String | Boolean.  If 1, include the values of all Contact Custom Fields in the report. Default is 0.
  email: 'email_example', # String | Filter results by matching any Contact email address containing the given string.
  domain: 'domain_example', # String | Filter results by matching any Contact email address in a domain name containing the given string.
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example' # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
}

begin
  result = api_instance.get_report_clicked(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling Marketing3Api->get_report_clicked: #{e}"
end

api_instance = Luxsci::Marketing3Api.new
username = 'username_example' # String | 
opts = { 
  campaign_ids: 'campaign_ids_example', # String | Select campaigns as string of comma-separated campaign ids.  If omitted, all campaigns are selected.
  use_date: 'use_date_example', # String | If set to \"sent\", use the date the message was sent, instead of the date of the open event, for date selections.
  detail: 'detail_example', # String | Boolean.  If 1, include the values of all Contact Custom Fields in the report. Default is 0.
  email: 'email_example', # String | Filter results by matching any Contact email address containing the given string.
  domain: 'domain_example', # String | Filter results by matching any Contact email address in a domain name containing the given string.
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example' # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
}

begin
  result = api_instance.get_report_complaints(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling Marketing3Api->get_report_complaints: #{e}"
end

api_instance = Luxsci::Marketing3Api.new
username = 'username_example' # String | 
opts = { 
  campaign_ids: 'campaign_ids_example', # String | Select campaigns as string of comma-separated campaign ids. If omitted, all campaigns are selected.
  detail: 'detail_example', # String | Boolean.  If 1, include the values of all Contact Custom Fields in the report. Default is 0.
  email: 'email_example', # String | Filter results by matching any Contact email address containing the given string.
  domain: 'domain_example', # String | Filter results by matching any Contact email address in a domain name containing the given string.
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example' # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
}

begin
  result = api_instance.get_report_logs(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling Marketing3Api->get_report_logs: #{e}"
end

api_instance = Luxsci::Marketing3Api.new
username = 'username_example' # String | 
opts = { 
  campaign_ids: 'campaign_ids_example', # String | Select campaigns as string of comma-separated campaign ids. If omitted, all campaigns are selected.
  use_date: 'use_date_example', # String | If set to \"sent\", use the date the message was sent, instead of the date of the open event, for date selections.
  detail: 'detail_example', # String | Boolean.  If 1, include the values of all Contact Custom Fields in the report. Default is 0.
  email: 'email_example', # String | Filter results by matching any Contact email address containing the given string.
  domain: 'domain_example', # String | Filter results by matching any Contact email address in a domain name containing the given string.
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example' # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
}

begin
  result = api_instance.get_report_opened(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling Marketing3Api->get_report_opened: #{e}"
end

api_instance = Luxsci::Marketing3Api.new
username = 'username_example' # String | 
opts = { 
  campaign_ids: 'campaign_ids_example', # String | Select campaigns as string of comma-separated campaign ids.  If omitted, all campaigns are selected.
  use_date: 'use_date_example', # String | If set to \"sent\", use the date the message was sent, instead of the date of the open event, for date selections.
  detail: 'detail_example', # String | Boolean.  If 1, include the values of all Contact Custom Fields in the report. Default is 0.
  email: 'email_example', # String | Filter results by matching any Contact email address containing the given string.
  domain: 'domain_example', # String | Filter results by matching any Contact email address in a domain name containing the given string.
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example' # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
}

begin
  result = api_instance.get_report_unsubscribed(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling Marketing3Api->get_report_unsubscribed: #{e}"
end

api_instance = Luxsci::Marketing3Api.new
username = 'username_example' # String | 
opts = { 
  campaign_ids: 'campaign_ids_example', # String | Select campaigns as string of comma-separated campaign ids.  If omitted, all campaigns are selected.
  use_date: 'use_date_example', # String | If set to \"sent\", use the date the message was sent, instead of the date of the open event, for date selections.
  detail: 'detail_example', # String | Boolean.  If 1, include the values of all Contact Custom Fields in the report. Default is 0.
  email: 'email_example', # String | Filter results by matching any Contact email address containing the given string.
  domain: 'domain_example', # String | Filter results by matching any Contact email address in a domain name containing the given string.
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example' # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
}

begin
  result = api_instance.get_report_urls(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling Marketing3Api->get_report_urls: #{e}"
end

api_instance = Luxsci::Marketing3Api.new
username = 'username_example' # String | 
campaign_id = 'campaign_id_example' # String | Campaign Id.
opts = { 
  body: Luxsci::SM3CampaignPUTBody.new, # SM3CampaignPUTBody | 
}

begin
  result = api_instance.update_campaign(username, campaign_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling Marketing3Api->update_campaign: #{e}"
end

api_instance = Luxsci::Marketing3Api.new
body = {
  "email" : "support@luxsci.com",
  "customer_id_custom_field" : 999,
  "list_id" : "28"
} # Hash<String, String> | A JSON object containing Contact properties.
username = 'username_example' # String | 
contact_id = 'contact_id_example' # String | Contact Id.
opts = { 
}

begin
  result = api_instance.update_contact(body, username, contact_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling Marketing3Api->update_contact: #{e}"
end

api_instance = Luxsci::Marketing3Api.new
body = Luxsci::SM3ListBody.new # SM3ListBody | A JSON object containing List properties.
username = 'username_example' # String | 
id = 'id_example' # String | List Id.
opts = { 
}

begin
  result = api_instance.update_list(body, username, id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling Marketing3Api->update_list: #{e}"
end

api_instance = Luxsci::Marketing3Api.new
username = 'username_example' # String | 
list_group_id = 'list_group_id_example' # String | Unique Id for this list group.
opts = { 
  body: Luxsci::ListGroupListGroupIdBody1.new, # ListGroupListGroupIdBody1 | 
}

begin
  result = api_instance.update_list_group(username, list_group_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling Marketing3Api->update_list_group: #{e}"
end

api_instance = Luxsci::ReportsApi.new
account_id = 'account_id_example' # String | 
job_id = 56 # Integer | 
opts = { 
}

begin
  result = api_instance.get_account_job(account_id, job_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling ReportsApi->get_account_job: #{e}"
end

api_instance = Luxsci::ReportsApi.new
account_id = 'account_id_example' # String | 
opts = { 
}

begin
  result = api_instance.get_account_jobs(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling ReportsApi->get_account_jobs: #{e}"
end

api_instance = Luxsci::ReportsApi.new
account_id = 'account_id_example' # String | 
opts = { 
  email: 'email_example', # String | Restrict the report to suppressions of this specific email address.
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example' # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
}

begin
  result = api_instance.get_account_suppression_report(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling ReportsApi->get_account_suppression_report: #{e}"
end

api_instance = Luxsci::ReportsApi.new
account_id = 'account_id_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  filter1: 'filter1_example', # String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  filter2: 'filter2_example', # String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  filter3: 'filter3_example' # String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
}

begin
  result = api_instance.get_account_suppression_summary_report(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling ReportsApi->get_account_suppression_summary_report: #{e}"
end

api_instance = Luxsci::ReportsApi.new
account_id = 'account_id_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  from: 'from_example', # String | Case-insensitive substring search of the message “From” email address
  subject: 'subject_example', # String | Case-insensitive substring search of the message subject (in UTF-8).
  to: 'to_example', # String | Case-insensitive substring search of all recipient email addresses.
  user_id: 56, # Integer | Restrict the report to the user with this specific User ID number.
}

begin
  result = api_instance.get_email_feed_back_loops_report_account(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling ReportsApi->get_email_feed_back_loops_report_account: #{e}"
end

api_instance = Luxsci::ReportsApi.new
account_id = 'account_id_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  filter1: 'filter1_example', # String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  filter2: 'filter2_example', # String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  filter3: 'filter3_example', # String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  from: 'from_example', # String | String Case-insensitive substring search of the message “From” email address
  subject: 'subject_example', # String | String Case-insensitive substring search of the message subject (in UTF-8).
  to: 'to_example', # String | String. Case-insensitive substring search of all recipient email addresses.
  user_id: 56, # Integer | Integer Restrict the report to the user with this specific User ID number.
}

begin
  result = api_instance.get_email_feed_back_loops_summary_report_account(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling ReportsApi->get_email_feed_back_loops_summary_report_account: #{e}"
end

api_instance = Luxsci::ReportsApi.new
account_id = 'account_id_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  from: 'from_example', # String | Case-insensitive substring search of the message “From” email address
  clicked: 56, # Integer | If specified, the results are restricted as follows:<br>clicked < 0 – select messages where click tracking was not enabled.<br>clicked = 0 – select messages where click tracking was enabled, but where no URLs have yet been clicked by the recipient.<br>clicked > 0 – select messages where one or more URLs have been clicked by the recipient. When “clicked” is positive, you will get one row back for each click; so,<i>you can get multiple rows per message</i>.<br><br>If a value for “clicked” is not specified, a value of “1” will be assumed.
  click_date: 'click_date_example', # String | If true, the ”click_date” field will be used for all date selections. If false or not specified, the sent date (“date_sent”) will be used.
  header1: 'header1_example', # String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  header1_operator: 'header1_operator_example', # String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  header1_value: 'header1_value_example', # String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  header2: 'header2_example', # String | Like “header1” but applies to searching the header 2 column.
  header2_operator: 'header2_operator_example', # String | Like “header1_operator” but applies to searching the header 2 column.
  header2_value: 'header2_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  header3: 'header3_example', # String | Like “header1” but applies to searching the header 3 column.
  header3_operator: 'header3_operator_example', # String | Like “header1_operator” but applies to searching the header 3 column.
  header3_value: 'header3_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  opened: 56, # Integer | If specified, the results are restricted as follows:<br>opened < 0 – select messages where open tracking was not enabled.<br>opened = 0 – select messages where open tracking was enabled, but which have not yet been opened.<br>opened > 0 – select messages where open tracking was enabled, and which have been opened at least once. 
  sendmail_id: 'sendmail_id_example', # String | String. Return only the messages with the specified sendmail_id
  sendmail_ids: 'sendmail_ids_example', # String | Comma-delimited list of up to 100 sendmail ids. Returns any matching messages.
  status: 'status_example', # String | Values:<br><b>delivered</b> – Accepted by the recipient’s email servers and presumed delivered. If bounce processing is enabled, then this status could change later to ba_soft_fail or ba_hard_fail.<br><b>perm_fail</b> – Messages that have permanently failed to be delivered to the recipient’s servers. If bounce processing is on, this status could change shortly to ba_soft_fail, depending on the nature of the failure message.<br><b>lost</b> – Messages where the tracking was lost and it is unclear if it was delivered or lost from the queue.<br><b>queued</b> – Message is in the email server queue still waiting to be delivered to the recipient.<br><b>not_queued</b> -- all statuses except \"queued\". <br><b>ba_soft_fail</b> – Soft failure bounces received (when talking to the recipient’s servers or after successful delivery to the recipient’s servers).<br><b>ba_hard_fail</b> – Hard failure bounces received after successful delivery to the recipient’s servers,<br><b>any_hard_fail</b> – Results for ba_hard_fail OR perm_fail. I.e., all hard/permanent failures.
  subject: 'subject_example', # String | Case-insensitive substring search of the message subject (in UTF8).
  template_id: 56, # Integer | Optional template ID to select results only for those messages sent using the specified template.  A value of 0 selects all.
  to: 'to_example', # String | Case-insensitive substring search of all recipient email addresses.
  tracked_headers: 'tracked_headers_example', # String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  user_id: 'user_id_example', # String | Restrict the report to the user with this specific User ID number
  url: 'url_example', # String | Substring match on the URL clicked.
}

begin
  result = api_instance.get_email_smtp_click_report_account(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling ReportsApi->get_email_smtp_click_report_account: #{e}"
end

api_instance = Luxsci::ReportsApi.new
account_id = 'account_id_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  filter1: 'filter1_example', # String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  filter2: 'filter2_example', # String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  filter3: 'filter3_example', # String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  from: 'from_example', # String | Case-insensitive substring search of the message “From” email address
  header1: 'header1_example', # String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  header1_operator: 'header1_operator_example', # String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  header1_value: 'header1_value_example', # String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  header2: 'header2_example', # String | Like “header1” but applies to searching the header 2 column.
  header2_operator: 'header2_operator_example', # String | Like “header1_operator” but applies to searching the header 2 column.
  header2_value: 'header2_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  header3: 'header3_example', # String | Like “header1” but applies to searching the header 3 column.
  header3_operator: 'header3_operator_example', # String | Like “header1_operator” but applies to searching the header 3 column.
  header3_value: 'header3_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  subject: 'subject_example', # String | Case-insensitive substring search of the message subject (in UTF8).
  tracked_headers: 'tracked_headers_example', # String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  template_id: 56, # Integer | Optional template ID to select results only for those messages sent using the specified template.  A value of 0 selects all.
  user_id: 'user_id_example', # String | Restrict the report to the user with this specific User ID number
  url: 'url_example', # String | Substring match on the URL clicked.
}

begin
  result = api_instance.get_email_smtp_click_summary_report_account(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling ReportsApi->get_email_smtp_click_summary_report_account: #{e}"
end

api_instance = Luxsci::ReportsApi.new
account_id = 'account_id_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  clicked: 56, # Integer | Integer. If specified, the results are restricted as follows:<br>clicked < 0 – select messages where URL click tracking was not enabled.<br>clicked = 0 – select messages where URL click tracking was enabled, but where there have as yet been no clicks on any clinks in the messages.<br>clicked > 0 – select messages where URL click tracking was enabled and where there have been N or more clicks on links in the same message to the same recipient. N, in this case, is the number that you have specified as the value of the “clicked” parameter. I.e., using a value of “1” matches all messages that have had a link clicked on.
  from: 'from_example', # String | String. Case-insensitive substring search of the message “From” email Address
  ip: 'ip_example', # String | String. Case-insensitive substring search of the sender IP address (for SMTP reports only).
  header1: 'header1_example', # String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  header1_operator: 'header1_operator_example', # String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  header1_value: 'header1_value_example', # String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  header2: 'header2_example', # String | Like “header1” but applies to searching the header 2 column.
  header2_operator: 'header2_operator_example', # String | Like “header1_operator” but applies to searching the header 2 column.
  header2_value: 'header2_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  header3: 'header3_example', # String | Like “header1” but applies to searching the header 3 column.
  header3_operator: 'header3_operator_example', # String | Like “header1_operator” but applies to searching the header 3 column.
  header3_value: 'header3_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  opened: 56, # Integer | Integer. If specified, the results are restricted as follows:<br>opened < 0 – select messages where open tracking was not enabled.<br>opened = 0 – select messages where open tracking was enabled, but which have not yet been opened.<br>opened > 0 – select messages where open tracking was enabled and which have been opened at least N times. N, in this case, is the number that you have specified as the value of the “opened” parameter. I.e., using a value of “1” matches all messages that have been opened.
  secureline: 'secureline_example', # String | Enum. Value:<br>u - message to this recipient did not use SecureLine (or Opt Out was used)<br>e - message did use SecureLine<br>-2 - SecureLine was not used due to Opt Out being selected<br>-1 - SecureLine usage not recorded for some reason<br>1 - SecureLine:PGP was used<br>2 - SecureLine:S/MIME was used<br>3 - SecureLine:Escrow was used<br>4 - SecureLine:TLS was used
  sendmail_id: 'sendmail_id_example', # String | String. Return only the messages with the specified sendmail_id
  sent_date: 56, # Integer | If set to true (i.e., 1), the email message sent date will be used for date/time selections, instead of the date of the last update of the row.
  state: 'state_example', # String | Optionally, match only messages with a specific delivery state/status.  Supported values include: \"delivered\" - message successfully delivered to recipient email servers; \"any_hard_fail\" - Either status: \"perm_fail\" or \"ba_hard_fail\"; \"lost\" - Message delivery status not determined; \"queued\" - Message currently queued for delivery (includes message status \"received\", \"queued\", and \"temp_fail\"); \"not_quueed\" - Message is no longer queued for delivery (it has been delivered, bounced, or failed); \"perm_fail\" - Message delivery rejected by the recipient servers; \"ba_soft_fail\" - A post-delivery soft bounce failure email message was received; \"ba_had_fail\" - A post-delivery hard bounce failure email message was received.
  state_detail: 'state_detail_example', # String | Optionally, match only messages where the \"state_detail\" delivery status description contains the specified text (case insensitive).
  delivery_date: 56, # Integer | If set to true (i.e., 1), the email message last delivery status updated date will be used for date/time selections, instead of the date of the last update of the row.
  sendmail_ids: 'sendmail_ids_example', # String | Comma-delimited list of up to 100 sendmail ids. Returns any matching messages.
  spam: 56, # Integer | Enum. Value:<br>0 – Message was not marked as spam by a recipient and returned in a Feed Back Loop.<br>1 – Message was marked as spam by a recipient and returned in a Feed Back Loop
  unsubscribed: 56, # Integer | Enum. Value:<br>0 – Recipient did not unsubscribe based on this email message.<br>1 – Recipeient did unsubscribe based on this email message.
  smtp_code: 'smtp_code_example', # String | String. 1-3 characters.  Substring match to the beginning of the smtp_code field.  E.g., 5 matches all codes starting with 5.
  tls: 56, # Integer | Enum. Value:<br>0 – TLS was NOT used in the successful delivery of this message to the recipient server<br>1 – TLS was used in the successful delivery of this message to the recipient server
  tracked_headers: 'tracked_headers_example', # String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  template_id: 56, # Integer | Optional template ID to select results only for those messages sent using the specified template.  A value of 0 selects all.
  to: 'to_example', # String | Case-insensitive substring search of all recipient email addresses.
  user_id: 56, # Integer | Integer. Restrict the report to the user with this specific User ID number
}

begin
  result = api_instance.get_email_smtp_delivery_status_report_account(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling ReportsApi->get_email_smtp_delivery_status_report_account: #{e}"
end

api_instance = Luxsci::ReportsApi.new
account_id = 'account_id_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  filter1: 'filter1_example', # String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  filter2: 'filter2_example', # String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  filter3: 'filter3_example', # String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  clicked: 56, # Integer | Integer. If specified, the results are restricted as follows:<br>clicked < 0 – select messages where URL click tracking was not enabled.<br>clicked = 0 – select messages where URL click tracking was enabled, but where there have as yet been no clicks on any clinks in the messages.<br>clicked > 0 – select messages where URL click tracking was enabled and where there have been N or more clicks on links in the same message to the same recipient. N, in this case, is the number that you have specified as the value of the “clicked” parameter. I.e., using a value of “1” matches all messages that have had a link clicked on.
  from: 'from_example', # String | String. Case-insensitive substring search of the message “From” email Address
  ip: 'ip_example', # String | String. Case-insensitive substring search of the sender IP address (for SMTP reports only).
  header1: 'header1_example', # String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  header1_operator: 'header1_operator_example', # String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  header1_value: 'header1_value_example', # String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  header2: 'header2_example', # String | Like “header1” but applies to searching the header 2 column.
  header2_operator: 'header2_operator_example', # String | Like “header1_operator” but applies to searching the header 2 column.
  header2_value: 'header2_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  header3: 'header3_example', # String | Like “header1” but applies to searching the header 3 column.
  header3_operator: 'header3_operator_example', # String | Like “header1_operator” but applies to searching the header 3 column.
  header3_value: 'header3_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  opened: 56, # Integer | Integer. If specified, the results are restricted as follows:<br>opened < 0 – select messages where open tracking was not enabled.<br>opened = 0 – select messages where open tracking was enabled, but which have not yet been opened.<br>opened > 0 – select messages where open tracking was enabled and which have been opened at least N times. N, in this case, is the number that you have specified as the value of the “opened” parameter. I.e., using a value of “1” matches all messages that have been opened.
  secureline: 'secureline_example', # String | Enum. Value:<br>u – Message to this recipient did not use SecureLine (or Opt Out was used)<br>e – Message did use SecureLine<br>-2 – SecureLine was not used due to Opt Out being selected<br>-1 – SecureLine usage not recorded for some reason<br>1 – SecureLine:PGP was used<br>2 – SecureLine:S/MIME was used<br>3 – SecureLine:Escrow was used<br>4 – SecureLine:TLS was used
  sent_date: 56, # Integer | If set to true (i.e., 1), the email message sent date will be used for date/time selections, instead of the date of the last update of the delivery status.
  queue_age_sec: 56, # Integer | If provided, then the \"queued\" and \"pct_queued\" results will reflect only those messages that have been not delivered for at least this number of seconds.  I.e., use this to eliminate very recently sent messages from your analysis or how mange messages were queued and not yet delivered.
  unsubscribed: 56, # Integer | Enum. Value: 0 – The recipient did not unsubscribe based on this email message. 1 – The recipient did unsubscribe based on this email message.
  tls: 56, # Integer | Enum. Value:<br>0 – TLS was NOT used in the successful delivery of this message to the recipient server<br>1 – TLS was used in the successful delivery of this message to the recipient server.
  tracked_headers: 'tracked_headers_example', # String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  template_id: 56, # Integer | Optional template ID to select results only for those messages sent using the specified template.  A value of 0 selects all.
  to: 'to_example', # String | Case-insensitive substring search of all recipient email addresses.
  user_id: 56, # Integer | Integer. Restrict the report to the user with this specific User ID number
}

begin
  result = api_instance.get_email_smtp_delivery_status_summary_report_account(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling ReportsApi->get_email_smtp_delivery_status_summary_report_account: #{e}"
end

api_instance = Luxsci::ReportsApi.new
account_id = 'account_id_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  from: 'from_example', # String | Case-insensitive substring search of the message “From” email address
  header1: 'header1_example', # String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  header1_operator: 'header1_operator_example', # String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  header1_value: 'header1_value_example', # String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  header2: 'header2_example', # String | Like “header1” but applies to searching the header 2 column.
  header2_operator: 'header2_operator_example', # String | Like “header1_operator” but applies to searching the header 2 column.
  header2_value: 'header2_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  header3: 'header3_example', # String | Like “header1” but applies to searching the header 3 column.
  header3_operator: 'header3_operator_example', # String | Like “header1_operator” but applies to searching the header 3 column.
  header3_value: 'header3_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  opened: 1, # Integer | If specified, the results are restricted as follows:<br>opened < 0 – select messages where open tracking was not enabled.<br>opened = 0 – select messages where open tracking was enabled, but which have not yet been opened.<br>opened > 0 – select messages where open tracking was enabled and which have been opened at least once. When opened is positive, you will get one row back for each open; so, <i>you can get multiple rows per message</i>.<br><br>If you do not specify a value for “opened”, a value of “1” will be assumed.
  open_date: true, # BOOLEAN | If true, the ”open_date” field will be used for all date selections. If false or not specified, the sent date (“date_sent”) will be used.
  sendmail_id: 'sendmail_id_example', # String | Return only the messages with the specified sendmail_id.
  sendmail_ids: 'sendmail_ids_example', # String | Comma-delimited list of up to 100 sendmail ids. Returns any matching messages.
  status: 'status_example', # String | Values:<br><b>delivered</b> – Accepted by the recipient’s email servers and presumed delivered. If bounce processing is enabled, then this status could change later to ba_soft_fail or ba_hard_fail.<br><b>perm_fail</b> – Messages that have permanently failed to be delivered to the recipient’s servers. If bounce processing is on, this status could change shortly to ba_soft_fail, depending on the nature of the failure message.<br><b>lost</b> – Messages where the tracking was lost and it is unclear if it was delivered or lost from the queue.<br><b>queued</b> – Message is in the email server queue still waiting to be delivered to the recipient.<br><b>not_queued</b> -- all statuses except \"queued\". <br><b>ba_soft_fail</b> – Soft failure bounces received (when talking to the recipient’s servers or after successful delivery to the recipient’s servers).<br><b>ba_hard_fail</b> – Hard failure bounces received after successful delivery to the recipient’s servers,<br><b>any_hard_fail</b> – Results for ba_hard_fail OR perm_fail. I.e., all hard/permanent failures.
  subject: 'subject_example', # String | Case-insensitive substring search of the message subject (in UTF8).
  template_id: 56, # Integer | Optional template ID to select results only for those messages sent using the specified template.  A value of 0 selects all.
  to: 'to_example', # String | Case-insensitive substring search of all recipient email addresses.
  tracked_headers: 'tracked_headers_example', # String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  user_id: 'user_id_example', # String | Restrict the report to the user with this specific User ID number
}

begin
  result = api_instance.get_email_smtp_open_report_account(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling ReportsApi->get_email_smtp_open_report_account: #{e}"
end

api_instance = Luxsci::ReportsApi.new
account_id = 'account_id_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  filter1: 'filter1_example', # String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  filter2: 'filter2_example', # String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  filter3: 'filter3_example', # String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  from: 'from_example', # String | Case-insensitive substring search of the message “From” email address
  header1: 'header1_example', # String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  header1_operator: 'header1_operator_example', # String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  header1_value: 'header1_value_example', # String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  header2: 'header2_example', # String | Like “header1” but applies to searching the header 2 column.
  header2_operator: 'header2_operator_example', # String | Like “header1_operator” but applies to searching the header 2 column.
  header2_value: 'header2_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  header3: 'header3_example', # String | Like “header1” but applies to searching the header 3 column.
  header3_operator: 'header3_operator_example', # String | Like “header1_operator” but applies to searching the header 3 column.
  header3_value: 'header3_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  opened: 1, # Integer | If specified, the results are restricted as follows:<br>opened < 0 – select messages where open tracking was not enabled.<br>opened = 0 – select messages where open tracking was enabled, but which have not yet been opened.<br>opened > 0 – select messages where open tracking was enabled and which have been opened at least once. When opened is positive, you will get one row back for each open; so, <i>you can get multiple rows per message</i>.<br><br>If you do not specify a value for “opened”, a value of “1” will be assumed.
  subject: 'subject_example', # String | Case-insensitive substring search of the message subject (in UTF8).
  to: 'to_example', # String | Case-insensitive substring search of all recipient email addresses.
  tracked_headers: 'tracked_headers_example', # String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  template_id: 56, # Integer | Optional template ID to select results only for those messages sent using the specified template.  A value of 0 selects all.
  user_id: 'user_id_example', # String | Restrict the report to the user with this specific User ID number
}

begin
  result = api_instance.get_email_smtp_open_summary_report_account(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling ReportsApi->get_email_smtp_open_summary_report_account: #{e}"
end

api_instance = Luxsci::ReportsApi.new
account_id = 'account_id_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  from: 'from_example', # String | Case-insensitive substring search of the message “From” email address
  header1: 'header1_example', # String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  header1_operator: 'header1_operator_example', # String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  header1_value: 'header1_value_example', # String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  header2: 'header2_example', # String | Like “header1” but applies to searching the header 2 column.
  header2_operator: 'header2_operator_example', # String | Like “header1_operator” but applies to searching the header 2 column.
  header2_value: 'header2_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  header3: 'header3_example', # String | Like “header1” but applies to searching the header 3 column.
  header3_operator: 'header3_operator_example', # String | Like “header1_operator” but applies to searching the header 3 column.
  header3_value: 'header3_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  ip: 'ip_example', # String | Case-insensitive substring search of the sender IP address (for SMTP reports only).
  opt_out: 'opt_out_example', # String | Value:<br>0 – SecureLine Opt Out not used<br>-1 – SecureLine Opt Out use not recorded for some reason<br>1 – SecureLine Opt Out
  secureline: 'secureline_example', # String | Value:<br>any – Match anything<br>-1 – SecureLine usage not recorded for some reason<br>1 – SecureLine encryption was used<br>0 – SecureLine encryption was not used<br><br>If SecureLine was used, use the delivery status report to see more details.
  sendmail_id: 'sendmail_id_example', # String | Return only the message with the specified sendmail_id.
  sendmail_ids: 'sendmail_ids_example', # String | Comma-delimited list of up to 100 sendmail ids. Returns any matching messages.
  spam: 'spam_example', # String | Value:<br>0 – Message was not marked as spam by a recipient and returned in a Feed Back Loop<br>1 – Message was marked as spam by a recipient and returned in a Feed Back Loop
  subject: 'subject_example', # String | Case-insensitive substring search of the message subject (in UTF-8).
  to: 'to_example', # String | Case-insensitive substring search of all recipient email addresses.
  tracked_headers: 'tracked_headers_example', # String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  template_id: 56, # Integer | Optional template ID to select results only for those messages sent using the specified template.  A value of 0 selects all.
  user_id: 'user_id_example', # String | Restrict the report to the user with this specific User ID number.
}

begin
  result = api_instance.get_email_smtp_sent_report_account(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling ReportsApi->get_email_smtp_sent_report_account: #{e}"
end

api_instance = Luxsci::ReportsApi.new
account_id = 'account_id_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  sendmail_id: 'sendmail_id_example', # String | String. Return temp failures only the messages with the specified sendmail_id
  sendmail_ids: 'sendmail_ids_example', # String | Comma-delimited list of up to 100 sendmail ids. Returns temporary failures for any matching messages.
  to: 'to_example', # String | Case-insensitive substring search of all recipient email addresses.
  user_id: 56, # Integer | Integer. Restrict the report to the user with this specific User ID number
}

begin
  result = api_instance.get_email_smtp_temp_fail_report_account(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling ReportsApi->get_email_smtp_temp_fail_report_account: #{e}"
end

api_instance = Luxsci::ReportsApi.new
account_id = 'account_id_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  from: 'from_example', # String | Case-insensitive substring search of the message “From” email address
  clicked: 56, # Integer | If specified, the results are restricted as follows:<br>clicked < 0 – select messages where click tracking was not enabled.<br>clicked = 0 – select messages where click tracking was enabled, but where no URLs have yet been clicked by the recipient.<br>clicked > 0 – select messages where one or more URLs have been clicked by the recipient. When “clicked” is positive, you will get one row back for each click; so,<i>you can get multiple rows per message</i>.<br><br>If a value for “clicked” is not specified, a value of “1” will be assumed.
  click_date: 'click_date_example', # String | If true, the ”click_date” field will be used for all date selections. If false or not specified, the sent date (“date_sent”) will be used.
  header1: 'header1_example', # String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  header1_operator: 'header1_operator_example', # String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  header1_value: 'header1_value_example', # String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  header2: 'header2_example', # String | Like “header1” but applies to searching the header 2 column.
  header2_operator: 'header2_operator_example', # String | Like “header1_operator” but applies to searching the header 2 column.
  header2_value: 'header2_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  header3: 'header3_example', # String | Like “header1” but applies to searching the header 3 column.
  header3_operator: 'header3_operator_example', # String | Like “header1_operator” but applies to searching the header 3 column.
  header3_value: 'header3_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  opened: 56, # Integer | If specified, the results are restricted as follows:<br>opened < 0 – select messages where open tracking was not enabled.<br>opened = 0 – select messages where open tracking was enabled, but which have not yet been opened.<br>opened > 0 – select messages where open tracking was enabled, and which have been opened at least once. 
  sendmail_id: 'sendmail_id_example', # String | String. Return only the messages with the specified sendmail_id
  sendmail_ids: 'sendmail_ids_example', # String | Comma-delimited list of up to 100 sendmail ids. Returns any matching messages.
  status: 'status_example', # String | Values:<br><b>delivered</b> – Accepted by the recipient’s email servers and presumed delivered. If bounce processing is enabled, then this status could change later to ba_soft_fail or ba_hard_fail.<br><b>perm_fail</b> – Messages that have permanently failed to be delivered to the recipient’s servers. If bounce processing is on, this status could change shortly to ba_soft_fail, depending on the nature of the failure message.<br><b>lost</b> – Messages where the tracking was lost and it is unclear if it was delivered or lost from the queue.<br><b>queued</b> – Message is in the email server queue still waiting to be delivered to the recipient.<br><b>not_queued</b> -- all statuses except \"queued\". <br><b>ba_soft_fail</b> – Soft failure bounces received (when talking to the recipient’s servers or after successful delivery to the recipient’s servers).<br><b>ba_hard_fail</b> – Hard failure bounces received after successful delivery to the recipient’s servers,<br><b>any_hard_fail</b> – Results for ba_hard_fail OR perm_fail. I.e., all hard/permanent failures.
  subject: 'subject_example', # String | Case-insensitive substring search of the message subject (in UTF8).
  to: 'to_example', # String | Case-insensitive substring search of all recipient email addresses.
  tracked_headers: 'tracked_headers_example', # String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  user_id: 'user_id_example', # String | Restrict the report to the user with this specific User ID number
  url: 'url_example', # String | Substring match on the URL clicked.
}

begin
  result = api_instance.get_email_web_mail_click_report_account(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling ReportsApi->get_email_web_mail_click_report_account: #{e}"
end

api_instance = Luxsci::ReportsApi.new
account_id = 'account_id_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  clicked: 56, # Integer | Integer. If specified, the results are restricted as follows:<br>clicked < 0 – select messages where URL click tracking was not enabled.<br>clicked = 0 – select messages where URL click tracking was enabled, but where there have as yet been no clicks on any clinks in the messages.<br>clicked > 0 – select messages where URL click tracking was enabled and where there have been N or more clicks on links in the same message to the same recipient. N, in this case, is the number that you have specified as the value of the “clicked” parameter. I.e., using a value of “1” matches all messages that have had a link clicked on.
  from: 'from_example', # String | String. Case-insensitive substring search of the message “From” email Address
  ip: 'ip_example', # String | String. Case-insensitive substring search of the sender IP address (for SMTP reports only).
  header1: 'header1_example', # String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  header1_operator: 'header1_operator_example', # String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  header1_value: 'header1_value_example', # String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  header2: 'header2_example', # String | Like “header1” but applies to searching the header 2 column.
  header2_operator: 'header2_operator_example', # String | Like “header1_operator” but applies to searching the header 2 column.
  header2_value: 'header2_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  header3: 'header3_example', # String | Like “header1” but applies to searching the header 3 column.
  header3_operator: 'header3_operator_example', # String | Like “header1_operator” but applies to searching the header 3 column.
  header3_value: 'header3_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  opened: 56, # Integer | Integer. If specified, the results are restricted as follows:<br>opened < 0 – select messages where open tracking was not enabled.<br>opened = 0 – select messages where open tracking was enabled, but which have not yet been opened.<br>opened > 0 – select messages where open tracking was enabled and which have been opened at least N times. N, in this case, is the number that you have specified as the value of the “opened” parameter. I.e., using a value of “1” matches all messages that have been opened.
  secureline: 'secureline_example', # String | Enum. Value:<br>u – Message to this recipient did not use SecureLine (or Opt Out was used)<br>e – Message did use SecureLine<br>-2 – SecureLine was not used due to Opt Out being selected<br>-1 – SecureLine usage not recorded for some reason<br>1 – SecureLine:PGP was used<br>2 – SecureLine:S/MIME was used<br>3 – SecureLine:Escrow was used<br>4 – SecureLine:TLS was used
  sendmail_id: 'sendmail_id_example', # String | String. Return only the messages with the specified sendmail_id
  sendmail_ids: 'sendmail_ids_example', # String | Comma-delimited list of up to 100 sendmail ids. Returns any matching messages.
  sent_date: 56, # Integer | If set to true (i.e., 1), the email message sent date will be used for date/time selections, instead of the date of the last update of the delivery status.
  spam: 56, # Integer | Enum. Value:<br>0 – Message was not marked as spam by a recipient and returned in a Feed Back Loop.<br>1 – Message was marked as spam by a recipient and returned in a Feed Back Loop
  tls: 56, # Integer | Enum. Value:<br>0 – TLS was NOT used in the successful delivery of this message to the recipient server<br>1 – TLS was used in the successful delivery of this message to the recipient server
  tracked_headers: 'tracked_headers_example', # String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  to: 'to_example', # String | Case-insensitive substring search of all recipient email addresses.
  user_id: 56, # Integer | Integer. Restrict the report to the user with this specific User ID number
}

begin
  result = api_instance.get_email_web_mail_delivery_status_report_account(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling ReportsApi->get_email_web_mail_delivery_status_report_account: #{e}"
end

api_instance = Luxsci::ReportsApi.new
account_id = 'account_id_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  from: 'from_example', # String | Case-insensitive substring search of the message “From” email address
  header1: 'header1_example', # String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  header1_operator: 'header1_operator_example', # String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  header1_value: 'header1_value_example', # String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  header2: 'header2_example', # String | Like “header1” but applies to searching the header 2 column.
  header2_operator: 'header2_operator_example', # String | Like “header1_operator” but applies to searching the header 2 column.
  header2_value: 'header2_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  header3: 'header3_example', # String | Like “header1” but applies to searching the header 3 column.
  header3_operator: 'header3_operator_example', # String | Like “header1_operator” but applies to searching the header 3 column.
  header3_value: 'header3_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  opened: 1, # Integer | If specified, the results are restricted as follows:<br>opened < 0 – select messages where open tracking was not enabled.<br>opened = 0 – select messages where open tracking was enabled, but which have not yet been opened.<br>opened > 0 – select messages where open tracking was enabled and which have been opened at least once. When opened is positive, you will get one row back for each open; so, <i>you can get multiple rows per message</i>.<br><br>If you do not specify a value for “opened”, a value of “1” will be assumed.
  open_date: true, # BOOLEAN | If true, the ”open_date” field will be used for all date selections. If false or not specified, the sent date (“date_sent”) will be used.
  sendmail_id: 'sendmail_id_example', # String | Return only the messages with the specified sendmail_id.
  sendmail_ids: 'sendmail_ids_example', # String | Comma-delimited list of up to 100 sendmail ids. Returns any matching messages.
  status: 'status_example', # String | Values:<br><b>delivered</b> – Accepted by the recipient’s email servers and presumed delivered. If bounce processing is enabled, then this status could change later to ba_soft_fail or ba_hard_fail.<br><b>perm_fail</b> – Messages that have permanently failed to be delivered to the recipient’s servers. If bounce processing is on, this status could change shortly to ba_soft_fail, depending on the nature of the failure message.<br><b>lost</b> – Messages where the tracking was lost and it is unclear if it was delivered or lost from the queue.<br><b>queued</b> – Message is in the email server queue still waiting to be delivered to the recipient.<br><b>not_queued</b> -- all statuses except \"queued\". <br><b>ba_soft_fail</b> – Soft failure bounces received (when talking to the recipient’s servers or after successful delivery to the recipient’s servers).<br><b>ba_hard_fail</b> – Hard failure bounces received after successful delivery to the recipient’s servers,<br><b>any_hard_fail</b> – Results for ba_hard_fail OR perm_fail. I.e., all hard/permanent failures.
  subject: 'subject_example', # String | Case-insensitive substring search of the message subject (in UTF8).
  to: 'to_example', # String | Case-insensitive substring search of all recipient email addresses.
  tracked_headers: 'tracked_headers_example', # String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  user_id: 'user_id_example', # String | Restrict the report to the user with this specific User ID number
}

begin
  result = api_instance.get_email_web_mail_open_report_account(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling ReportsApi->get_email_web_mail_open_report_account: #{e}"
end

api_instance = Luxsci::ReportsApi.new
account_id = 'account_id_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  from: 'from_example', # String | Case-insensitive substring search of the message “From” email address
  header1: 'header1_example', # String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  header1_operator: 'header1_operator_example', # String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  header1_value: 'header1_value_example', # String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  header2: 'header2_example', # String | Like “header1” but applies to searching the header 2 column.
  header2_operator: 'header2_operator_example', # String | Like “header1_operator” but applies to searching the header 2 column.
  header2_value: 'header2_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  header3: 'header3_example', # String | Like “header1” but applies to searching the header 3 column.
  header3_operator: 'header3_operator_example', # String | Like “header1_operator” but applies to searching the header 3 column.
  header3_value: 'header3_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  ip: 'ip_example', # String | Case-insensitive substring search of the sender IP address (for SMTP reports only).
  opt_out: 'opt_out_example', # String | Value:<br>0 – SecureLine Opt Out not used<br>-1 – SecureLine Opt Out use not recorded for some reason<br>1 – SecureLine Opt Out
  secureline: 'secureline_example', # String | Value:<br>any – Match anything<br>-1 – SecureLine usage not recorded for some reason<br>1 – SecureLine encryption was used<br>0 – SecureLine encryption was not used<br><br>If SecureLine was used, use the delivery status report to see more details.
  sendmail_id: 'sendmail_id_example', # String | Return only the message with the specified sendmail_id.
  sendmail_ids: 'sendmail_ids_example', # String | Comma-delimited list of up to 100 sendmail ids. Returns any matching messages.
  spam: 'spam_example', # String | Value:<br>0 – Message was not marked as spam by a recipient and returned in a Feed Back Loop<br>1 – Message was marked as spam by a recipient and returned in a Feed Back Loop
  subject: 'subject_example', # String | Case-insensitive substring search of the message subject (in UTF-8).
  to: 'to_example', # String | Case-insensitive substring search of all recipient email addresses.
  tracked_headers: 'tracked_headers_example', # String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  user_id: 'user_id_example', # String | Restrict the report to the user with this specific User ID number.
}

begin
  result = api_instance.get_email_web_mail_sent_report_account(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling ReportsApi->get_email_web_mail_sent_report_account: #{e}"
end

api_instance = Luxsci::ReportsApi.new
account_id = 'account_id_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  ip: 'ip_example', # String | String. Case-insensitive substring search of the message “IP Address” if the email program or device that made the connection.
  reason: 'reason_example', # String | String Case-insensitive substring search of the login failure / reason data.
}

begin
  result = api_instance.get_smtp_login_failure_report_account(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling ReportsApi->get_smtp_login_failure_report_account: #{e}"
end

api_instance = Luxsci::SecureFormApi.new
account_id = 'account_id_example' # String | 
form_id = 'form_id_example' # String | 
row_index = 'row_index_example' # String | 
file_index = 'file_index_example' # String | 
opts = { 
}

begin
  result = api_instance.delete_secure_form_database_file(account_id, form_id, row_index, file_index, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling SecureFormApi->delete_secure_form_database_file: #{e}"
end

api_instance = Luxsci::SecureFormApi.new
account_id = 'account_id_example' # String | 
form_id = 'form_id_example' # String | 
index = 'index_example' # String | 
opts = { 
}

begin
  result = api_instance.delete_secure_form_database_row(account_id, form_id, index, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling SecureFormApi->delete_secure_form_database_row: #{e}"
end

api_instance = Luxsci::SecureFormApi.new
account_id = 'account_id_example' # String | 
form_id = 'form_id_example' # String | 
opts = { 
}

begin
  result = api_instance.get_secure_form(account_id, form_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling SecureFormApi->get_secure_form: #{e}"
end

api_instance = Luxsci::SecureFormApi.new
account_id = 'account_id_example' # String | 
form_id = 'form_id_example' # String | 
row_index = 'row_index_example' # String | 
file_index = 'file_index_example' # String | 
opts = { 
}

begin
  result = api_instance.get_secure_form_database_file(account_id, form_id, row_index, file_index, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling SecureFormApi->get_secure_form_database_file: #{e}"
end

api_instance = Luxsci::SecureFormApi.new
account_id = 'account_id_example' # String | 
form_id = 'form_id_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. All rows added after thes pecified date time (in GMT, format “YYYY-MM-DD HH:MM:SS”).
  after_index: 56, # Integer | All rows whose index is greater than the specified value
  before_date: 'before_date_example', # String | DATETIME. All rows added before the specified date time
  before_index: 56, # Integer | All rows whose index is less than the specified value
  from_date: 'from_date_example', # String | DATETIME. All rows added on or after the specified date time
  from_index: 56, # Integer | All rows whose index is greater than or equal to the specified value.
  through_date: 'through_date_example', # String | DATETIME. All rows added on or before the specified date time
  through_index: 56, # Integer | All rows whose index is less than or equal to the specified value.
}

begin
  result = api_instance.get_secure_form_database_posts(account_id, form_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling SecureFormApi->get_secure_form_database_posts: #{e}"
end

api_instance = Luxsci::SecureFormApi.new
account_id = 'account_id_example' # String | 
form_id = 'form_id_example' # String | 
index = 'index_example' # String | 
opts = { 
}

begin
  result = api_instance.get_secure_form_database_row(account_id, form_id, index, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling SecureFormApi->get_secure_form_database_row: #{e}"
end

api_instance = Luxsci::SecureFormApi.new
account_id = 'account_id_example' # String | 
form_id = 'form_id_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. All rows added after thes pecified date time (in GMT, format “YYYY-MM-DD HH:MM:SS”).
  after_index: 56, # Integer | All rows whose index is greater than the specified value
  before_date: 'before_date_example', # String | DATETIME. All rows added before the specified date time
  before_index: 56, # Integer | All rows whose index is less than the specified value
  from_date: 'from_date_example', # String | DATETIME. All rows added on or after the specified date time
  from_index: 56, # Integer | All rows whose index is greater than or equal to the specified value.
  through_date: 'through_date_example', # String | DATETIME. All rows added on or before the specified date time
  through_index: 56, # Integer | All rows whose index is less than or equal to the specified value.
}

begin
  result = api_instance.get_secure_form_database_rows(account_id, form_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling SecureFormApi->get_secure_form_database_rows: #{e}"
end

api_instance = Luxsci::SecureFormApi.new
account_id = 'account_id_example' # String | 
opts = { 
}

begin
  result = api_instance.get_secure_form_list(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling SecureFormApi->get_secure_form_list: #{e}"
end

api_instance = Luxsci::SecureSendApi.new
account_id = 'account_id_example' # String | 
namespace_id = 'namespace_id_example' # String | 
username = 'username_example' # String | 
opts = { 
  body: Luxsci::UsernamePasswordBody1.new, # UsernamePasswordBody1 | 
}

begin
  result = api_instance.change_secure_send_user_password(account_id, namespace_id, username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling SecureSendApi->change_secure_send_user_password: #{e}"
end

api_instance = Luxsci::SecureSendApi.new
account_id = 'account_id_example' # String | 
namespace_id = 'namespace_id_example' # String | 
username = 'username_example' # String | 
opts = { 
  body: Luxsci::UsersUsernameBody1.new, # UsersUsernameBody1 | 
}

begin
  result = api_instance.create_or_update_secure_send_user(account_id, namespace_id, username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling SecureSendApi->create_or_update_secure_send_user: #{e}"
end

api_instance = Luxsci::SecureSendApi.new
account_id = 'account_id_example' # String | 
namespace_id = 'namespace_id_example' # String | 
opts = { 
}

begin
  result = api_instance.get_secure_send_user_list(account_id, namespace_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling SecureSendApi->get_secure_send_user_list: #{e}"
end

api_instance = Luxsci::SecureSendApi.new
account_id = 'account_id_example' # String | 
namespace_id = 'namespace_id_example' # String | 
username = 'username_example' # String | 
opts = { 
  ip: 'ip_example', # String | The public IP address that the user is currently using. The resulting URL will only work for people accessing it from this IP.
  theme: 56, # Integer | The numerical Private Labeled Theme ID that this link should be generated for. You can find these IDs in your theme management area.<br><br>Not that the SecureSend NameSpace specified must be associated with this Theme, or the API will return an error.
}

begin
  result = api_instance.get_secure_send_user_single_sign_on_link(account_id, namespace_id, username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling SecureSendApi->get_secure_send_user_single_sign_on_link: #{e}"
end

api_instance = Luxsci::ServersApi.new
account_id = 'account_id_example' # String | 
server_id = 'server_id_example' # String | Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id.
opts = { 
}

begin
  result = api_instance.get_server_status(account_id, server_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling ServersApi->get_server_status: #{e}"
end

api_instance = Luxsci::ServersApi.new
account_id = 'account_id_example' # String | 
opts = { 
}

begin
  result = api_instance.get_servers(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling ServersApi->get_servers: #{e}"
end

api_instance = Luxsci::ServersApi.new
account_id = 'account_id_example' # String | 
server_id = 'server_id_example' # String | Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id.
opts = { 
}

begin
  api_instance.server_empty_all_email_queues(account_id, server_id, opts)
rescue Luxsci::ApiError => e
  puts "Exception when calling ServersApi->server_empty_all_email_queues: #{e}"
end

api_instance = Luxsci::ServersApi.new
account_id = 'account_id_example' # String | 
server_id = 'server_id_example' # String | Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id.
opts = { 
}

begin
  api_instance.server_empty_email_queues(account_id, server_id, opts)
rescue Luxsci::ApiError => e
  puts "Exception when calling ServersApi->server_empty_email_queues: #{e}"
end

api_instance = Luxsci::ServersApi.new
account_id = 'account_id_example' # String | 
server_id = 'server_id_example' # String | Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id.
opts = { 
  body: Luxsci::ServerIdSendingRateBody.new, # ServerIdSendingRateBody | 
}

begin
  api_instance.set_server_sendng_rate(account_id, server_id, opts)
rescue Luxsci::ApiError => e
  puts "Exception when calling ServersApi->set_server_sendng_rate: #{e}"
end

api_instance = Luxsci::UserReportsApi.new
username = 'username_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  from: 'from_example', # String | String Case-insensitive substring search of the message “From” email address
  subject: 'subject_example', # String | String Case-insensitive substring search of the message subject (in UTF-8).
  to: 'to_example', # String | String. Case-insensitive substring search of all recipient email addresses.
  user_id: 56, # Integer | Integer Restrict the report to the user with this specific User ID number.
}

begin
  result = api_instance.get_email_feed_back_loops_report_user(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UserReportsApi->get_email_feed_back_loops_report_user: #{e}"
end

api_instance = Luxsci::UserReportsApi.new
username = 'username_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  filter1: 'filter1_example', # String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  filter2: 'filter2_example', # String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  filter3: 'filter3_example', # String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  from: 'from_example', # String | String Case-insensitive substring search of the message “From” email address
  subject: 'subject_example', # String | String Case-insensitive substring search of the message subject (in UTF-8).
  to: 'to_example', # String | String. Case-insensitive substring search of all recipient email addresses.
  user_id: 56, # Integer | Integer Restrict the report to the user with this specific User ID number.
}

begin
  result = api_instance.get_email_feed_back_loops_summary_report_user(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UserReportsApi->get_email_feed_back_loops_summary_report_user: #{e}"
end

api_instance = Luxsci::UserReportsApi.new
username = 'username_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  from: 'from_example', # String | Case-insensitive substring search of the message “From” email address
  clicked: 56, # Integer | If specified, the results are restricted as follows:<br>clicked < 0 – select messages where click tracking was not enabled.<br>clicked = 0 – select messages where click tracking was enabled, but where no URLs have yet been clicked by the recipient.<br>clicked > 0 – select messages where one or more URLs have been clicked by the recipient. When “clicked” is positive, you will get one row back for each click; so,<i>you can get multiple rows per message</i>.<br><br>If a value for “clicked” is not specified, a value of “1” will be assumed.
  click_date: 'click_date_example', # String | If true, the ”click_date” field will be used for all date selections. If false or not specified, the sent date (“date_sent”) will be used.
  header1: 'header1_example', # String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  header1_operator: 'header1_operator_example', # String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  header1_value: 'header1_value_example', # String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  header2: 'header2_example', # String | Like “header1” but applies to searching the header 2 column.
  header2_operator: 'header2_operator_example', # String | Like “header1_operator” but applies to searching the header 2 column.
  header2_value: 'header2_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  header3: 'header3_example', # String | Like “header1” but applies to searching the header 3 column.
  header3_operator: 'header3_operator_example', # String | Like “header1_operator” but applies to searching the header 3 column.
  header3_value: 'header3_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  opened: 56, # Integer | If specified, the results are restricted as follows:<br>opened < 0 – select messages where open tracking was not enabled.<br>opened = 0 – select messages where open tracking was enabled, but which have not yet been opened.<br>opened > 0 – select messages where open tracking was enabled, and which have been opened at least once. 
  sendmail_id: 'sendmail_id_example', # String | String. Return only the messages with the specified sendmail_id
  sendmail_ids: 'sendmail_ids_example', # String | Comma-delimited list of up to 100 sendmail ids. Returns any matching messages.
  status: 'status_example', # String | Values:<br><b>delivered</b> – Accepted by the recipient’s email servers and presumed delivered. If bounce processing is enabled, then this status could change later to ba_soft_fail or ba_hard_fail.<br><b>perm_fail</b> – Messages that have permanently failed to be delivered to the recipient’s servers. If bounce processing is on, this status could change shortly to ba_soft_fail, depending on the nature of the failure message.<br><b>lost</b> – Messages where the tracking was lost and it is unclear if it was delivered or lost from the queue.<br><b>queued</b> – Message is in the email server queue still waiting to be delivered to the recipient.<br><b>not_queued</b> -- all statuses except \"queued\". <br><b>ba_soft_fail</b> – Soft failure bounces received (when talking to the recipient’s servers or after successful delivery to the recipient’s servers).<br><b>ba_hard_fail</b> – Hard failure bounces received after successful delivery to the recipient’s servers,<br><b>any_hard_fail</b> – Results for ba_hard_fail OR perm_fail. I.e., all hard/permanent failures.
  subject: 'subject_example', # String | Case-insensitive substring search of the message subject (in UTF8).
  to: 'to_example', # String | Case-insensitive substring search of all recipient email addresses.
  tracked_headers: 'tracked_headers_example', # String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  template_id: 56, # Integer | Optional template ID to select results only for those messages sent using the specified template.  A value of 0 selects all.
  user_id: 'user_id_example', # String | Restrict the report to the user with this specific User ID number
  url: 'url_example', # String | Substring match on the URL clicked.
}

begin
  result = api_instance.get_email_smtp_click_report_user(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UserReportsApi->get_email_smtp_click_report_user: #{e}"
end

api_instance = Luxsci::UserReportsApi.new
username = 'username_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  filter1: 'filter1_example', # String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  filter2: 'filter2_example', # String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  filter3: 'filter3_example', # String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  from: 'from_example', # String | Case-insensitive substring search of the message “From” email address
  header1: 'header1_example', # String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  header1_operator: 'header1_operator_example', # String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  header1_value: 'header1_value_example', # String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  header2: 'header2_example', # String | Like “header1” but applies to searching the header 2 column.
  header2_operator: 'header2_operator_example', # String | Like “header1_operator” but applies to searching the header 2 column.
  header2_value: 'header2_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  header3: 'header3_example', # String | Like “header1” but applies to searching the header 3 column.
  header3_operator: 'header3_operator_example', # String | Like “header1_operator” but applies to searching the header 3 column.
  header3_value: 'header3_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  subject: 'subject_example', # String | Case-insensitive substring search of the message subject (in UTF8).
  tracked_headers: 'tracked_headers_example', # String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  template_id: 56, # Integer | Optional template ID to select results only for those messages sent using the specified template.  A value of 0 selects all.
  user_id: 'user_id_example', # String | Restrict the report to the user with this specific User ID number
  url: 'url_example', # String | Substring match on the URL clicked.
}

begin
  result = api_instance.get_email_smtp_click_summary_report_user(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UserReportsApi->get_email_smtp_click_summary_report_user: #{e}"
end

api_instance = Luxsci::UserReportsApi.new
username = 'username_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  clicked: 56, # Integer | Integer. If specified, the results are restricted as follows:<br>clicked < 0 – select messages where URL click tracking was not enabled.<br>clicked = 0 – select messages where URL click tracking was enabled, but where there have as yet been no clicks on any clinks in the messages.<br>clicked > 0 – select messages where URL click tracking was enabled and where there have been N or more clicks on links in the same message to the same recipient. N, in this case, is the number that you have specified as the value of the “clicked” parameter. I.e., using a value of “1” matches all messages that have had a link clicked on.
  from: 'from_example', # String | String. Case-insensitive substring search of the message “From” email Address
  ip: 'ip_example', # String | String. Case-insensitive substring search of the sender IP address (for SMTP reports only).
  header1: 'header1_example', # String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  header1_operator: 'header1_operator_example', # String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  header1_value: 'header1_value_example', # String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  header2: 'header2_example', # String | Like “header1” but applies to searching the header 2 column.
  header2_operator: 'header2_operator_example', # String | Like “header1_operator” but applies to searching the header 2 column.
  header2_value: 'header2_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  header3: 'header3_example', # String | Like “header1” but applies to searching the header 3 column.
  header3_operator: 'header3_operator_example', # String | Like “header1_operator” but applies to searching the header 3 column.
  header3_value: 'header3_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  opened: 56, # Integer | Integer. If specified, the results are restricted as follows:<br>opened < 0 – select messages where open tracking was not enabled.<br>opened = 0 – select messages where open tracking was enabled, but which have not yet been opened.<br>opened > 0 – select messages where open tracking was enabled and which have been opened at least N times. N, in this case, is the number that you have specified as the value of the “opened” parameter. I.e., using a value of “1” matches all messages that have been opened.
  secureline: 'secureline_example', # String | Enum. Value:<br>u – Message to this recipient did not use SecureLine (or Opt Out was used)<br>e – Message did use SecureLine<br>-2 – SecureLine was not used due to Opt Out being selected<br>-1 – SecureLine usage not recorded for some reason<br>1 – SecureLine:PGP was used<br>2 – SecureLine:S/MIME was used<br>3 – SecureLine:Escrow was used<br>4 – SecureLine:TLS was used
  sendmail_id: 'sendmail_id_example', # String | String. Return only the messages with the specified sendmail_id
  sendmail_ids: 'sendmail_ids_example', # String | Comma-delimited list of up to 100 sendmail ids. Returns any matching messages.
  sent_date: 56, # Integer | If set to true (i.e., 1), the email message sent date will be used for date/time selections, instead of the date of the last update of the row.
  state: 'state_example', # String | Optionally, match only messages with a specific delivery state/status.  Supported values include: \"delivered\" - message successfully delivered to recipient email servers; \"any_hard_fail\" - Either status: \"perm_fail\" or \"ba_hard_fail\"; \"lost\" - Message delivery status not determined; \"queued\" - Message currently queued for delivery (includes message status \"received\", \"queued\", and \"temp_fail\"); \"not_quueed\" - Message is no longer queued for delivery (it has been delivered, bounced, or failed); \"perm_fail\" - Message delivery rejected by the recipient servers; \"ba_soft_fail\" - A post-delivery soft bounce failure email message was received; \"ba_had_fail\" - A post-delivery hard bounce failure email message was received.
  state_detail: 'state_detail_example', # String | Optionally, match only messages where the \"state_detail\" delivery status description contains the specified text (case insensitive).
  delivery_date: 56, # Integer | If set to true (i.e., 1), the email message last delivery status updated date will be used for date/time selections, instead of the date of the last update of the row.
  spam: 56, # Integer | Enum. Value:<br>0 – Message was not marked as spam by a recipient and returned in a Feed Back Loop.<br>1 – Message was marked as spam by a recipient and returned in a Feed Back Loop
  unsubscribed: 56, # Integer | Enum. Value: 0 – The recipient did not unsubscribe based on this email message. 1 – The recipient did unsubscribe based on this email message.
  smtp_code: 'smtp_code_example', # String | String. 1-3 characters.  Substring match to the beginning of the smtp_code field.  E.g., 5 matches all codes starting with 5.
  tls: 56, # Integer | Enum. Value:<br>0 – TLS was NOT used in the successful delivery of this message to the recipient server<br>1 – TLS was used in the successful delivery of this message to the recipient server.
  tracked_headers: 'tracked_headers_example', # String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  template_id: 56, # Integer | Optional template ID to select results only for those messages sent using the specified template.  A value of 0 selects all.
  to: 'to_example', # String | Case-insensitive substring search of all recipient email addresses.
  user_id: 56, # Integer | Integer. Restrict the report to the user with this specific User ID number
}

begin
  result = api_instance.get_email_smtp_delivery_status_report_user(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UserReportsApi->get_email_smtp_delivery_status_report_user: #{e}"
end

api_instance = Luxsci::UserReportsApi.new
username = 'username_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  filter1: 'filter1_example', # String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  filter2: 'filter2_example', # String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  filter3: 'filter3_example', # String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  clicked: 56, # Integer | Integer. If specified, the results are restricted as follows:<br>clicked < 0 – select messages where URL click tracking was not enabled.<br>clicked = 0 – select messages where URL click tracking was enabled, but where there have as yet been no clicks on any clinks in the messages.<br>clicked > 0 – select messages where URL click tracking was enabled and where there have been N or more clicks on links in the same message to the same recipient. N, in this case, is the number that you have specified as the value of the “clicked” parameter. I.e., using a value of “1” matches all messages that have had a link clicked on.
  from: 'from_example', # String | String. Case-insensitive substring search of the message “From” email Address
  ip: 'ip_example', # String | String. Case-insensitive substring search of the sender IP address (for SMTP reports only).
  header1: 'header1_example', # String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  header1_operator: 'header1_operator_example', # String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  header1_value: 'header1_value_example', # String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  header2: 'header2_example', # String | Like “header1” but applies to searching the header 2 column.
  header2_operator: 'header2_operator_example', # String | Like “header1_operator” but applies to searching the header 2 column.
  header2_value: 'header2_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  header3: 'header3_example', # String | Like “header1” but applies to searching the header 3 column.
  header3_operator: 'header3_operator_example', # String | Like “header1_operator” but applies to searching the header 3 column.
  header3_value: 'header3_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  opened: 56, # Integer | Integer. If specified, the results are restricted as follows:<br>opened < 0 – select messages where open tracking was not enabled.<br>opened = 0 – select messages where open tracking was enabled, but which have not yet been opened.<br>opened > 0 – select messages where open tracking was enabled and which have been opened at least N times. N, in this case, is the number that you have specified as the value of the “opened” parameter. I.e., using a value of “1” matches all messages that have been opened.
  secureline: 'secureline_example', # String | Enum. Value:<br>u – Message to this recipient did not use SecureLine (or Opt Out was used)<br>e – Message did use SecureLine<br>-2 – SecureLine was not used due to Opt Out being selected<br>-1 – SecureLine usage not recorded for some reason<br>1 – SecureLine:PGP was used<br>2 – SecureLine:S/MIME was used<br>3 – SecureLine:Escrow was used<br>4 – SecureLine:TLS was used
  sent_date: 56, # Integer | If set to true (i.e., 1), the email message sent date will be used for date/time selections, instead of the date of the last update of the delivery status.
  queue_age_sec: 56, # Integer | If provided, then the \"queued\" and \"pct_queued\" results will reflect only those messages that have been not delivered for at least this number of seconds.  I.e., use this to eliminate very recently sent messages from your analysis or how mange messages were queued and not yet delivered.
  unsubscribed: 56, # Integer | Enum. Value: 0 – The recipient did not unsubscribe based on this email message. 1 – The recipient did unsubscribe based on this email message.
  tls: 56, # Integer | Enum. Value:<br>0 – TLS was NOT used in the successful delivery of this message to the recipient server<br>1 – TLS was used in the successful delivery of this message to the recipient server.
  tracked_headers: 'tracked_headers_example', # String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  template_id: 56, # Integer | Optional template ID to select results only for those messages sent using the specified template.  A value of 0 selects all.
  to: 'to_example', # String | Case-insensitive substring search of all recipient email addresses.
}

begin
  result = api_instance.get_email_smtp_delivery_status_summary_report_user(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UserReportsApi->get_email_smtp_delivery_status_summary_report_user: #{e}"
end

api_instance = Luxsci::UserReportsApi.new
username = 'username_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  ip: 'ip_example', # String | String. Case-insensitive substring search of the message “IP Address” if the email program or device that made the connection.
  reason: 'reason_example', # String | String Case-insensitive substring search of the login failure / reason data.
}

begin
  result = api_instance.get_email_smtp_login_failure_report_user(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UserReportsApi->get_email_smtp_login_failure_report_user: #{e}"
end

api_instance = Luxsci::UserReportsApi.new
username = 'username_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  from: 'from_example', # String | Case-insensitive substring search of the message “From” email address
  header1: 'header1_example', # String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  header1_operator: 'header1_operator_example', # String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  header1_value: 'header1_value_example', # String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  header2: 'header2_example', # String | Like “header1” but applies to searching the header 2 column.
  header2_operator: 'header2_operator_example', # String | Like “header1_operator” but applies to searching the header 2 column.
  header2_value: 'header2_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  header3: 'header3_example', # String | Like “header1” but applies to searching the header 3 column.
  header3_operator: 'header3_operator_example', # String | Like “header1_operator” but applies to searching the header 3 column.
  header3_value: 'header3_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  opened: 1, # Integer | If specified, the results are restricted as follows:<br>opened < 0 – select messages where open tracking was not enabled.<br>opened = 0 – select messages where open tracking was enabled, but which have not yet been opened.<br>opened > 0 – select messages where open tracking was enabled and which have been opened at least once. When opened is positive, you will get one row back for each open; so, <i>you can get multiple rows per message</i>.<br><br>If you do not specify a value for “opened”, a value of “1” will be assumed.
  open_date: true, # BOOLEAN | If true, the ”open_date” field will be used for all date selections. If false or not specified, the sent date (“date_sent”) will be used.
  sendmail_id: 'sendmail_id_example', # String | Return only the messages with the specified sendmail_id.
  sendmail_ids: 'sendmail_ids_example', # String | Comma-delimited list of up to 100 sendmail ids. Returns any matching messages.
  status: 'status_example', # String | Values:<br><b>delivered</b> – Accepted by the recipient’s email servers and presumed delivered. If bounce processing is enabled, then this status could change later to ba_soft_fail or ba_hard_fail.<br><b>perm_fail</b> – Messages that have permanently failed to be delivered to the recipient’s servers. If bounce processing is on, this status could change shortly to ba_soft_fail, depending on the nature of the failure message.<br><b>lost</b> – Messages where the tracking was lost and it is unclear if it was delivered or lost from the queue.<br><b>queued</b> – Message is in the email server queue still waiting to be delivered to the recipient.<br><b>not_queued</b> -- all statuses except \"queued\". <br><b>ba_soft_fail</b> – Soft failure bounces received (when talking to the recipient’s servers or after successful delivery to the recipient’s servers).<br><b>ba_hard_fail</b> – Hard failure bounces received after successful delivery to the recipient’s servers,<br><b>any_hard_fail</b> – Results for ba_hard_fail OR perm_fail. I.e., all hard/permanent failures.
  subject: 'subject_example', # String | Case-insensitive substring search of the message subject (in UTF8).
  to: 'to_example', # String | Case-insensitive substring search of all recipient email addresses.
  tracked_headers: 'tracked_headers_example', # String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  template_id: 56, # Integer | Optional template ID to select results only for those messages sent using the specified template.  A value of 0 selects all.
}

begin
  result = api_instance.get_email_smtp_open_report_user(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UserReportsApi->get_email_smtp_open_report_user: #{e}"
end

api_instance = Luxsci::UserReportsApi.new
username = 'username_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  filter1: 'filter1_example', # String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  filter2: 'filter2_example', # String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  filter3: 'filter3_example', # String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  from: 'from_example', # String | Case-insensitive substring search of the message “From” email address
  header1: 'header1_example', # String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  header1_operator: 'header1_operator_example', # String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  header1_value: 'header1_value_example', # String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  header2: 'header2_example', # String | Like “header1” but applies to searching the header 2 column.
  header2_operator: 'header2_operator_example', # String | Like “header1_operator” but applies to searching the header 2 column.
  header2_value: 'header2_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  header3: 'header3_example', # String | Like “header1” but applies to searching the header 3 column.
  header3_operator: 'header3_operator_example', # String | Like “header1_operator” but applies to searching the header 3 column.
  header3_value: 'header3_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  opened: 1, # Integer | If specified, the results are restricted as follows:<br>opened < 0 – select messages where open tracking was not enabled.<br>opened = 0 – select messages where open tracking was enabled, but which have not yet been opened.<br>opened > 0 – select messages where open tracking was enabled and which have been opened at least once. When opened is positive, you will get one row back for each open; so, <i>you can get multiple rows per message</i>.<br><br>If you do not specify a value for “opened”, a value of “1” will be assumed.
  subject: 'subject_example', # String | Case-insensitive substring search of the message subject (in UTF8).
  to: 'to_example', # String | Case-insensitive substring search of all recipient email addresses.
  tracked_headers: 'tracked_headers_example', # String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  template_id: 56, # Integer | Optional template ID to select results only for those messages sent using the specified template.  A value of 0 selects all.
}

begin
  result = api_instance.get_email_smtp_open_summary_report_user(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UserReportsApi->get_email_smtp_open_summary_report_user: #{e}"
end

api_instance = Luxsci::UserReportsApi.new
username = 'username_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  from: 'from_example', # String | Case-insensitive substring search of the message “From” email address
  header1: 'header1_example', # String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  header1_operator: 'header1_operator_example', # String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  header1_value: 'header1_value_example', # String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  header2: 'header2_example', # String | Like “header1” but applies to searching the header 2 column.
  header2_operator: 'header2_operator_example', # String | Like “header1_operator” but applies to searching the header 2 column.
  header2_value: 'header2_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  header3: 'header3_example', # String | Like “header1” but applies to searching the header 3 column.
  header3_operator: 'header3_operator_example', # String | Like “header1_operator” but applies to searching the header 3 column.
  header3_value: 'header3_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  ip: 'ip_example', # String | Case-insensitive substring search of the sender IP address (for SMTP reports only).
  opt_out: 'opt_out_example', # String | Value:<br>0 – SecureLine Opt Out not used<br>-1 – SecureLine Opt Out use not recorded for some reason<br>1 – SecureLine Opt Out
  secureline: 'secureline_example', # String | Value:<br>any – Match anything<br>-1 – SecureLine usage not recorded for some reason<br>1 – SecureLine encryption was used<br>0 – SecureLine encryption was not used<br><br>If SecureLine was used, use the delivery status report to see more details.
  sendmail_id: 'sendmail_id_example', # String | Return only the message with the specified sendmail_id.
  sendmail_ids: 'sendmail_ids_example', # String | Comma-delimited list of up to 100 sendmail ids. Returns any matching messages.
  spam: 'spam_example', # String | Value:<br>0 – Message was not marked as spam by a recipient and returned in a Feed Back Loop<br>1 – Message was marked as spam by a recipient and returned in a Feed Back Loop
  subject: 'subject_example', # String | Case-insensitive substring search of the message subject (in UTF-8).
  to: 'to_example', # String | Case-insensitive substring search of all recipient email addresses.
  template_id: 56, # Integer | Optional template ID to select results only for those messages sent using the specified template.  A value of 0 selects all.
  tracked_headers: 'tracked_headers_example', # String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  user_id: 'user_id_example', # String | Restrict the report to the user with this specific User ID number.
}

begin
  result = api_instance.get_email_smtp_sent_report_user(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UserReportsApi->get_email_smtp_sent_report_user: #{e}"
end

api_instance = Luxsci::UserReportsApi.new
account_id = 'account_id_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  sendmail_id: 'sendmail_id_example', # String | String. Return temp failures only the messages with the specified sendmail_id
  sendmail_ids: 'sendmail_ids_example', # String | Comma-delimited list of up to 100 sendmail ids. Returns temporary failures for any matching messages.
  to: 'to_example', # String | Case-insensitive substring search of all recipient email addresses.
}

begin
  result = api_instance.get_email_smtp_temp_fail_report_user(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UserReportsApi->get_email_smtp_temp_fail_report_user: #{e}"
end

api_instance = Luxsci::UserReportsApi.new
username = 'username_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  from: 'from_example', # String | Case-insensitive substring search of the message “From” email address
  clicked: 56, # Integer | If specified, the results are restricted as follows:<br>clicked < 0 – select messages where click tracking was not enabled.<br>clicked = 0 – select messages where click tracking was enabled, but where no URLs have yet been clicked by the recipient.<br>clicked > 0 – select messages where one or more URLs have been clicked by the recipient. When “clicked” is positive, you will get one row back for each click; so,<i>you can get multiple rows per message</i>.<br><br>If a value for “clicked” is not specified, a value of “1” will be assumed.
  click_date: 'click_date_example', # String | If true, the ”click_date” field will be used for all date selections. If false or not specified, the sent date (“date_sent”) will be used.
  header1: 'header1_example', # String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  header1_operator: 'header1_operator_example', # String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  header1_value: 'header1_value_example', # String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  header2: 'header2_example', # String | Like “header1” but applies to searching the header 2 column.
  header2_operator: 'header2_operator_example', # String | Like “header1_operator” but applies to searching the header 2 column.
  header2_value: 'header2_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  header3: 'header3_example', # String | Like “header1” but applies to searching the header 3 column.
  header3_operator: 'header3_operator_example', # String | Like “header1_operator” but applies to searching the header 3 column.
  header3_value: 'header3_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  opened: 56, # Integer | If specified, the results are restricted as follows:<br>opened < 0 – select messages where open tracking was not enabled.<br>opened = 0 – select messages where open tracking was enabled, but which have not yet been opened.<br>opened > 0 – select messages where open tracking was enabled, and which have been opened at least once. 
  sendmail_id: 'sendmail_id_example', # String | String. Return only the messages with the specified sendmail_id
  sendmail_ids: 'sendmail_ids_example', # String | Comma-delimited list of up to 100 sendmail ids. Returns any matching messages.
  status: 'status_example', # String | Values:<br><b>delivered</b> – Accepted by the recipient’s email servers and presumed delivered. If bounce processing is enabled, then this status could change later to ba_soft_fail or ba_hard_fail.<br><b>perm_fail</b> – Messages that have permanently failed to be delivered to the recipient’s servers. If bounce processing is on, this status could change shortly to ba_soft_fail, depending on the nature of the failure message.<br><b>lost</b> – Messages where the tracking was lost and it is unclear if it was delivered or lost from the queue.<br><b>queued</b> – Message is in the email server queue still waiting to be delivered to the recipient.<br><b>not_queued</b> -- all statuses except \"queued\". <br><b>ba_soft_fail</b> – Soft failure bounces received (when talking to the recipient’s servers or after successful delivery to the recipient’s servers).<br><b>ba_hard_fail</b> – Hard failure bounces received after successful delivery to the recipient’s servers,<br><b>any_hard_fail</b> – Results for ba_hard_fail OR perm_fail. I.e., all hard/permanent failures.
  subject: 'subject_example', # String | Case-insensitive substring search of the message subject (in UTF8).
  to: 'to_example', # String | Case-insensitive substring search of all recipient email addresses.
  tracked_headers: 'tracked_headers_example', # String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  user_id: 'user_id_example', # String | Restrict the report to the user with this specific User ID number
  url: 'url_example', # String | Substring match on the URL clicked.
}

begin
  result = api_instance.get_email_web_mail_click_report_user(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UserReportsApi->get_email_web_mail_click_report_user: #{e}"
end

api_instance = Luxsci::UserReportsApi.new
username = 'username_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  clicked: 56, # Integer | Integer. If specified, the results are restricted as follows:<br>clicked < 0 – select messages where URL click tracking was not enabled.<br>clicked = 0 – select messages where URL click tracking was enabled, but where there have as yet been no clicks on any clinks in the messages.<br>clicked > 0 – select messages where URL click tracking was enabled and where there have been N or more clicks on links in the same message to the same recipient. N, in this case, is the number that you have specified as the value of the “clicked” parameter. I.e., using a value of “1” matches all messages that have had a link clicked on.
  from: 'from_example', # String | String. Case-insensitive substring search of the message “From” email Address
  ip: 'ip_example', # String | String. Case-insensitive substring search of the sender IP address (for SMTP reports only).
  header1: 'header1_example', # String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  header1_operator: 'header1_operator_example', # String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  header1_value: 'header1_value_example', # String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  header2: 'header2_example', # String | Like “header1” but applies to searching the header 2 column.
  header2_operator: 'header2_operator_example', # String | Like “header1_operator” but applies to searching the header 2 column.
  header2_value: 'header2_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  header3: 'header3_example', # String | Like “header1” but applies to searching the header 3 column.
  header3_operator: 'header3_operator_example', # String | Like “header1_operator” but applies to searching the header 3 column.
  header3_value: 'header3_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  opened: 56, # Integer | Integer. If specified, the results are restricted as follows:<br>opened < 0 – select messages where open tracking was not enabled.<br>opened = 0 – select messages where open tracking was enabled, but which have not yet been opened.<br>opened > 0 – select messages where open tracking was enabled and which have been opened at least N times. N, in this case, is the number that you have specified as the value of the “opened” parameter. I.e., using a value of “1” matches all messages that have been opened.
  secureline: 'secureline_example', # String | Enum. Value:<br>u – Message to this recipient did not use SecureLine (or Opt Out was used)<br>e – Message did use SecureLine<br>-2 – SecureLine was not used due to Opt Out being selected<br>-1 – SecureLine usage not recorded for some reason<br>1 – SecureLine:PGP was used<br>2 – SecureLine:S/MIME was used<br>3 – SecureLine:Escrow was used<br>4 – SecureLine:TLS was used
  sendmail_id: 'sendmail_id_example', # String | String. Return only the messages with the specified sendmail_id
  sendmail_ids: 'sendmail_ids_example', # String | Comma-delimited list of up to 100 sendmail ids. Returns any matching messages.
  sent_date: 56, # Integer | If set to true (i.e., 1), the email message sent date will be used for date/time selections, instead of the date of the last update of the delivery status.
  spam: 56, # Integer | Enum. Value:<br>0 – Message was not marked as spam by a recipient and returned in a Feed Back Loop.<br>1 – Message was marked as spam by a recipient and returned in a Feed Back Loop
  tls: 56, # Integer | Enum. Value:<br>0 – TLS was NOT used in the successful delivery of this message to the recipient server<br>1 – TLS was used in the successful delivery of this message to the recipient server
  tracked_headers: 'tracked_headers_example', # String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  to: 'to_example', # String | Case-insensitive substring search of all recipient email addresses.
  user_id: 56, # Integer | Integer. Restrict the report to the user with this specific User ID number
}

begin
  result = api_instance.get_email_web_mail_delivery_status_report_user(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UserReportsApi->get_email_web_mail_delivery_status_report_user: #{e}"
end

api_instance = Luxsci::UserReportsApi.new
username = 'username_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  from: 'from_example', # String | Case-insensitive substring search of the message “From” email address
  header1: 'header1_example', # String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  header1_operator: 'header1_operator_example', # String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  header1_value: 'header1_value_example', # String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  header2: 'header2_example', # String | Like “header1” but applies to searching the header 2 column.
  header2_operator: 'header2_operator_example', # String | Like “header1_operator” but applies to searching the header 2 column.
  header2_value: 'header2_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  header3: 'header3_example', # String | Like “header1” but applies to searching the header 3 column.
  header3_operator: 'header3_operator_example', # String | Like “header1_operator” but applies to searching the header 3 column.
  header3_value: 'header3_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  opened: 1, # Integer | If specified, the results are restricted as follows:<br>opened < 0 – select messages where open tracking was not enabled.<br>opened = 0 – select messages where open tracking was enabled, but which have not yet been opened.<br>opened > 0 – select messages where open tracking was enabled and which have been opened at least once. When opened is positive, you will get one row back for each open; so, <i>you can get multiple rows per message</i>.<br><br>If you do not specify a value for “opened”, a value of “1” will be assumed.
  open_date: true, # BOOLEAN | If true, the ”open_date” field will be used for all date selections. If false or not specified, the sent date (“date_sent”) will be used.
  sendmail_id: 'sendmail_id_example', # String | Return only the messages with the specified sendmail_id.
  sendmail_ids: 'sendmail_ids_example', # String | Comma-delimited list of up to 100 sendmail ids. Returns any matching messages.
  status: 'status_example', # String | Values:<br><b>delivered</b> – Accepted by the recipient’s email servers and presumed delivered. If bounce processing is enabled, then this status could change later to ba_soft_fail or ba_hard_fail.<br><b>perm_fail</b> – Messages that have permanently failed to be delivered to the recipient’s servers. If bounce processing is on, this status could change shortly to ba_soft_fail, depending on the nature of the failure message.<br><b>lost</b> – Messages where the tracking was lost and it is unclear if it was delivered or lost from the queue.<br><b>queued</b> – Message is in the email server queue still waiting to be delivered to the recipient.<br><b>not_queued</b> -- all statuses except \"queued\". <br><b>ba_soft_fail</b> – Soft failure bounces received (when talking to the recipient’s servers or after successful delivery to the recipient’s servers).<br><b>ba_hard_fail</b> – Hard failure bounces received after successful delivery to the recipient’s servers,<br><b>any_hard_fail</b> – Results for ba_hard_fail OR perm_fail. I.e., all hard/permanent failures.
  subject: 'subject_example', # String | Case-insensitive substring search of the message subject (in UTF8).
  to: 'to_example', # String | Case-insensitive substring search of all recipient email addresses.
  tracked_headers: 'tracked_headers_example', # String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  user_id: 'user_id_example', # String | Restrict the report to the user with this specific User ID number
}

begin
  result = api_instance.get_email_web_mail_open_report_user(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UserReportsApi->get_email_web_mail_open_report_user: #{e}"
end

api_instance = Luxsci::UserReportsApi.new
username = 'username_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  from: 'from_example', # String | Case-insensitive substring search of the message “From” email address
  header1: 'header1_example', # String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  header1_operator: 'header1_operator_example', # String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  header1_value: 'header1_value_example', # String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  header2: 'header2_example', # String | Like “header1” but applies to searching the header 2 column.
  header2_operator: 'header2_operator_example', # String | Like “header1_operator” but applies to searching the header 2 column.
  header2_value: 'header2_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  header3: 'header3_example', # String | Like “header1” but applies to searching the header 3 column.
  header3_operator: 'header3_operator_example', # String | Like “header1_operator” but applies to searching the header 3 column.
  header3_value: 'header3_value_example', # String | Like “header1_value” but applies to searching the header 2 column.
  ip: 'ip_example', # String | Case-insensitive substring search of the sender IP address (for SMTP reports only).
  opt_out: 'opt_out_example', # String | Value:<br>0 – SecureLine Opt Out not used<br>-1 – SecureLine Opt Out use not recorded for some reason<br>1 – SecureLine Opt Out
  secureline: 'secureline_example', # String | Value:<br>any – Match anything<br>-1 – SecureLine usage not recorded for some reason<br>1 – SecureLine encryption was used<br>0 – SecureLine encryption was not used<br><br>If SecureLine was used, use the delivery status report to see more details.
  sendmail_id: 'sendmail_id_example', # String | Return only the message with the specified sendmail_id.
  sendmail_ids: 'sendmail_ids_example', # String | Comma-delimited list of up to 100 sendmail ids. Returns any matching messages.
  spam: 'spam_example', # String | Value:<br>0 – Message was not marked as spam by a recipient and returned in a Feed Back Loop<br>1 – Message was marked as spam by a recipient and returned in a Feed Back Loop
  subject: 'subject_example', # String | Case-insensitive substring search of the message subject (in UTF-8).
  to: 'to_example', # String | Case-insensitive substring search of all recipient email addresses.
  tracked_headers: 'tracked_headers_example', # String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  user_id: 'user_id_example', # String | Restrict the report to the user with this specific User ID number.
}

begin
  result = api_instance.get_email_web_mail_sent_report_user(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UserReportsApi->get_email_web_mail_sent_report_user: #{e}"
end

api_instance = Luxsci::UserReportsApi.new
username = 'username_example' # String | 
job_id = 56 # Integer | 
opts = { 
}

begin
  result = api_instance.get_user_job(username, job_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UserReportsApi->get_user_job: #{e}"
end

api_instance = Luxsci::UserReportsApi.new
username = 'username_example' # String | 
opts = { 
}

begin
  result = api_instance.get_user_jobs(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UserReportsApi->get_user_jobs: #{e}"
end

api_instance = Luxsci::UserReportsApi.new
username = 'username_example' # String | 
opts = { 
  email: 'email_example', # String | Restrict the report to suppressions of this specific email address.
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example' # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
}

begin
  result = api_instance.get_user_suppression_report(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UserReportsApi->get_user_suppression_report: #{e}"
end

api_instance = Luxsci::UserReportsApi.new
username = 'username_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  filter1: 'filter1_example', # String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  filter2: 'filter2_example', # String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  filter3: 'filter3_example' # String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
}

begin
  result = api_instance.get_user_suppression_summary_report(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UserReportsApi->get_user_suppression_summary_report: #{e}"
end

api_instance = Luxsci::UsersApi.new
username = 'username_example' # String | 
opts = { 
  body: Luxsci::UsernamePasswordBody.new # UsernamePasswordBody | 
}

begin
  result = api_instance.change_user_password(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->change_user_password: #{e}"
end

api_instance = Luxsci::UsersApi.new
username = 'username_example' # String | 
suffix = 'suffix_example' # String | It is the plain text suffix to the user’s regular login email address that will be used to create this new app-specific password. E.g., if you specify “email” as the suffix for the user ‘user@domain.com’, then the new login will be ‘usr@domain.com/email’.  The suffix string must be 1-10 characters long and can only contain letters and numbers. It is also case insensitive (so will be converted to lower case).'
opts = { 
  body: Luxsci::ApppasswordSuffixBody.new, # ApppasswordSuffixBody | 
}

begin
  result = api_instance.create_app_specific_password(username, suffix, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->create_app_specific_password: #{e}"
end

api_instance = Luxsci::UsersApi.new
account_id = 'account_id_example' # String | 
opts = { 
  body: Luxsci::AccountIdUsersBody.new, # AccountIdUsersBody | 
}

begin
  result = api_instance.create_user(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->create_user: #{e}"
end

api_instance = Luxsci::UsersApi.new
username = 'username_example' # String | 
suffix = 'suffix_example' # String | It is the plain text suffix to the user’s regular login email address that will be used to identify the app-specific password. E.g., if you specify “email” as the suffix for the user ‘user@ domain.com’, then the login deleted will be ‘usr@domain.com/email’.
opts = { 
}

begin
  result = api_instance.delete_app_specific_password(username, suffix, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->delete_app_specific_password: #{e}"
end

api_instance = Luxsci::UsersApi.new
account_id = 'account_id_example' # String | 
username = 'username_example' # String | 
opts = { 
}

begin
  result = api_instance.delete_user(account_id, username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->delete_user: #{e}"
end

api_instance = Luxsci::UsersApi.new
username = 'username_example' # String | 
opts = { 
}

begin
  result = api_instance.get_time_zones_list(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->get_time_zones_list: #{e}"
end

api_instance = Luxsci::UsersApi.new
username = 'username_example' # String | 
opts = { 
}

begin
  result = api_instance.get_user(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->get_user: #{e}"
end

api_instance = Luxsci::UsersApi.new
username = 'username_example' # String | 
opts = { 
}

begin
  result = api_instance.get_user_branding_information(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->get_user_branding_information: #{e}"
end

api_instance = Luxsci::UsersApi.new
username = 'username_example' # String | 
opts = { 
}

begin
  result = api_instance.get_user_profile(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->get_user_profile: #{e}"
end

api_instance = Luxsci::UsersApi.new
account_id = 'account_id_example' # String | 
opts = { 
  status: 'status_example', # String | Value ‘enabled’ – return only active/enabled users.<br>Value ‘disabled’ – return only disabled users.
  domain: 'domain_example', # String | Domain name in your account. If supplied, only users in this domain will be returned.
  younger_than: 56, # Integer | Return only users created less than this number of days ago.
  older_than: 56, # Integer | Return only users created more than this number of days ago.
}

begin
  result = api_instance.get_user_report(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->get_user_report: #{e}"
end

api_instance = Luxsci::UsersApi.new
account_id = 'account_id_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  status: 'status_example', # String | Specify one of enabled or disabled to retrieve only enabled or disabled users.
  domain: 'domain_example', # String | Enter the name of a domain to retrieve only users whose login is in that domain.
}

begin
  result = api_instance.get_user_report2(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->get_user_report2: #{e}"
end

api_instance = Luxsci::UsersApi.new
username = 'username_example' # String | 
opts = { 
}

begin
  result = api_instance.get_user_settings(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->get_user_settings: #{e}"
end

api_instance = Luxsci::UsersApi.new
username = 'username_example' # String | Optional. Path after the domain name to take the user to upon automatic sign in. If omitted, the default path of “/perl/member/email/messages.pl” will be used; this default takes one to view the WebMail INBOX folder. You can use this parameter to select other destinations.
ip = 'ip_example' # String | Required. This must be the IPv4 IP address that the end user is currently using. The resulting login URL will only work for someone who is coming from this specific IP address.
opts = { 
}

begin
  result = api_instance.get_user_single_sign_on_login_url(username, ip, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->get_user_single_sign_on_login_url: #{e}"
end

api_instance = Luxsci::UsersApi.new
account_id = 'account_id_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  status: 'status_example', # String | Specify one of enabled or disabled to retrieve only enabled or disabled users.
  domain: 'domain_example', # String | Enter the name of a domain to retrieve only users whose login is in that domain.
}

begin
  result = api_instance.get_user_summary_report(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->get_user_summary_report: #{e}"
end

api_instance = Luxsci::UsersApi.new
username = 'username_example' # String | 
opts = { 
}

begin
  result = api_instance.list_all_app_specific_password(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->list_all_app_specific_password: #{e}"
end

api_instance = Luxsci::UsersApi.new
username = 'username_example' # String | 
suffix = 'suffix_example' # String | 
opts = { 
}

begin
  result = api_instance.list_app_specific_passwords(username, suffix, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->list_app_specific_passwords: #{e}"
end

api_instance = Luxsci::UsersApi.new
account_id = 'account_id_example' # String | 
username = 'username_example' # String | 
opts = { 
  body: Luxsci::UsernameRenameBody.new, # UsernameRenameBody | 
}

begin
  result = api_instance.rename_user(account_id, username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->rename_user: #{e}"
end

api_instance = Luxsci::UsersApi.new
username = 'username_example' # String | 
opts = { 
  body: Luxsci::UserUsernameBody.new, # UserUsernameBody | 
}

begin
  result = api_instance.update_user(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->update_user: #{e}"
end

api_instance = Luxsci::UsersApi.new
username = 'username_example' # String | 
opts = { 
  body: Luxsci::UsernameProfileBody.new, # UsernameProfileBody | 
}

begin
  result = api_instance.update_user_profile(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->update_user_profile: #{e}"
end

api_instance = Luxsci::UsersApi.new
account_id = 'account_id_example' # String | 
username = 'username_example' # String | 
opts = { 
  body: Luxsci::UsersUsernameBody.new, # UsersUsernameBody | 
}

begin
  result = api_instance.update_user_settings(account_id, username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->update_user_settings: #{e}"
end

api_instance = Luxsci::WebAidesApi.new
username = 'username_example' # String | 
webaide_type = 'webaide_type_example' # String | 
webaide_id = 'webaide_id_example' # String | 
opts = { 
  body: Luxsci::EntriesImportBody.new, # EntriesImportBody | 
}

begin
  result = api_instance.add_update_web_aide_entries(username, webaide_type, webaide_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling WebAidesApi->add_update_web_aide_entries: #{e}"
end

api_instance = Luxsci::WebAidesApi.new
username = 'username_example' # String | 
webaide_type = 'webaide_type_example' # String | 
webaide_id = 'webaide_id_example' # String | 
opts = { 
}

begin
  result = api_instance.delete_web_aide(username, webaide_type, webaide_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling WebAidesApi->delete_web_aide: #{e}"
end

api_instance = Luxsci::WebAidesApi.new
username = 'username_example' # String | 
webaide_type = 'webaide_type_example' # String | 
webaide_id = 'webaide_id_example' # String | 
opts = { 
  body: Luxsci::EntriesDeleteBody.new, # EntriesDeleteBody | 
}

begin
  result = api_instance.delete_web_aide_entries(username, webaide_type, webaide_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling WebAidesApi->delete_web_aide_entries: #{e}"
end

api_instance = Luxsci::WebAidesApi.new
username = 'username_example' # String | 
webaide_type = 'webaide_type_example' # String | 
webaide_id = 'webaide_id_example' # String | 
entry_id = 'entry_id_example' # String | 
opts = { 
}

begin
  result = api_instance.delete_web_aide_entry(username, webaide_type, webaide_id, entry_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling WebAidesApi->delete_web_aide_entry: #{e}"
end

api_instance = Luxsci::WebAidesApi.new
username = 'username_example' # String | 
webaide_id = 'webaide_id_example' # String | 
before = 'before_example' # String | DATE: “YYYY-MM-DD” in GMT (where 00:00:00 GMT is implied) Required. Entries that contain events before this date.
from = 'from_example' # String | DATE: “YYYY-MM-DD” in GMT (where 00:00:00 GMT is implied)<br><br>Required. Entries that contain events on or after this date.
opts = { 
  entries: 'entries_example', # String | Comma-delimited list of entry Unique IDs. e.g. “10786,77892,23”<br><br>Optional. If included, the search is restricted to only entries in this list.<br><br>Note, if you want to use a very long list of entries, you might want to use several requests so that you do not exceed the maximum URL query string size of 8190 bytes.
}

begin
  result = api_instance.get_calendar_entries_date_range(username, webaide_id, before, from, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling WebAidesApi->get_calendar_entries_date_range: #{e}"
end

api_instance = Luxsci::WebAidesApi.new
username = 'username_example' # String | 
webaide_type = 'webaide_type_example' # String | 
webaide_id = 'webaide_id_example' # String | 
opts = { 
  changes: 'changes_example', # String | Optional. DateTime in GMT in the format: YYYY-MM-DD HH:MM:SS. If this is provided, a sub call to “GetWebAideChanges” will be made for each returned WebAide, giving you summary counts of numbers of entries and adds/updates/deletes since the specified date.<br><br>Specify an old date (e.g. “2000-01-01”) if all you care about is the total number of entries.<br><br>Use of “changes” is the recommended way to get the number of entries in one or more WebAides in an efficient manner.
}

begin
  result = api_instance.get_web_aide(username, webaide_type, webaide_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling WebAidesApi->get_web_aide: #{e}"
end

api_instance = Luxsci::WebAidesApi.new
username = 'username_example' # String | 
webaide_type = 'webaide_type_example' # String | 
webaide_id = 'webaide_id_example' # String | 
modified = 'modified_example' # String | Timestamp “YYYYMMDDHHMMSS” in GMT or “YYYY-MM-DD HH:MM:SS” in GMT<br><br>Return all WebAide entries added, changed, or deleted since this timestamp. If you specify “0” here, it will return a list of all entries that exist now and all that have been deleted.
opts = { 
}

begin
  result = api_instance.get_web_aide_changes(username, webaide_type, webaide_id, modified, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling WebAidesApi->get_web_aide_changes: #{e}"
end

api_instance = Luxsci::WebAidesApi.new
username = 'username_example' # String | 
webaide_type = 'webaide_type_example' # String | 
webaide_id = 'webaide_id_example' # String | 
opts = { 
  entries: ['entries_example'], # Array<String> | Optional. Comma-delimited list of entry Unique IDs. e.g. “10786,77892,23”.  If included, the search is restricted to only entries in this list.  Note, if you want to use a very long list of entries, you might want to use several requests so that you do not exceed the maximum URL query string size of 8190 bytes.
  limit: 500, # Integer | Optional. Integer 1 to 500. How many entries to return (maximum). Default is 500.
  resume: 0, # Integer | Integer:1 or 0. If 0 (the default), begin a new search. If 1, continue the previous search. When returning successive “pages” or entries, use resume for faster and more consistent results.
  secureline: 56, # Integer | Integer 1 or 0 If specified as ‘1’, SecureLine-specific Address Book fields are included in the export. I.e., this includes the SecureLine Escrow Question/Answer pair and/or PGP and S/MIME public keys.
  showcomplete: 56, # Integer | Integer 1 or 0 If specified as ‘1’, get completed tasks for ‘Tasks’ WebAides. By default, only uncompleted tasks are returned.
  sort: 'sort_example', # String | Optional method by which the returned entries should be sorted.
  start: 0, # Integer | Optional. The default is 0. Index in the list of all entries from which to start the result set. Use this to return successive “pages” of entries.
  timezone: 'timezone_example', # String | Time zone code. The time zone to use for Calendar/Task dates and times. The user’s default time zone is used if no time zone is specified.
}

begin
  result = api_instance.get_web_aide_entries(username, webaide_type, webaide_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling WebAidesApi->get_web_aide_entries: #{e}"
end

api_instance = Luxsci::WebAidesApi.new
username = 'username_example' # String | 
webaide_type = 'webaide_type_example' # String | 
webaide_id = 'webaide_id_example' # String | 
entry_id = 'entry_id_example' # String | 
opts = { 
}

begin
  result = api_instance.get_web_aide_entry(username, webaide_type, webaide_id, entry_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling WebAidesApi->get_web_aide_entry: #{e}"
end

api_instance = Luxsci::WebAidesApi.new
username = 'username_example' # String | 
webaide_type = 'webaide_type_example' # String | 
opts = { 
  subscribed: 'subscribed_example', # String | Filter by WebAide subscription status<ul><li>all - select all</li><li>subscribed - return those subscribed</li><li>unsubscribed - return those not subscribed</li><li>tosync - return those tagged for synchronization with MobileSync.</li>
  ids: ['ids_example'], # Array<String> | List of the numerical WebAide IDs eligible to be returned.
  permissions: ['permissions_example'], # Array<String> | Values can include those in the webaide_permission list. Select only WebAides where the user has all of the indicated permissions
  modified: 'modified_example', # String | DateTime in GMT in the format: YYYY-MM-DD HH:MM:SS. Return all WebAides that have had any entry created, deleted, or modified on or after this date and time. Values can include those in the webaide_permission list.
  changes: 'changes_example', # String | Optional. DateTime in GMT in the format: YYYY-MM-DD HH:MM:SS. If this is provided, a sub call to “GetWebAideChanges” will be made for each returned WebAide, giving you summary counts of numbers of entries and adds/ updates/deletes since the specified date.<br><br>Specify an old date (e.g. “2000-01-01”) if all you care about is the total number of entries.<br><br>Use of “changes” is the recommended way to get the number of entries in one or more WebAides in an efficient manner.
}

begin
  result = api_instance.get_web_aides(username, webaide_type, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling WebAidesApi->get_web_aides: #{e}"
end

api_instance = Luxsci::WebAidesApi.new
username = 'username_example' # String | 
webaide_type = 'webaide_type_example' # String | 
opts = { 
  body: Luxsci::WebaidesWebaideTypeBody.new, # WebaidesWebaideTypeBody | 
}

begin
  result = api_instance.new_web_aide(username, webaide_type, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling WebAidesApi->new_web_aide: #{e}"
end

api_instance = Luxsci::WebAidesApi.new
username = 'username_example' # String | 
webaide_type = 'webaide_type_example' # String | 
webaide_id = 'webaide_id_example' # String | 
opts = { 
  body: Luxsci::WebaideTypeWebaideIdBody.new, # WebaideTypeWebaideIdBody | 
}

begin
  result = api_instance.new_web_aide_entry(username, webaide_type, webaide_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling WebAidesApi->new_web_aide_entry: #{e}"
end

api_instance = Luxsci::WebAidesApi.new
username = 'username_example' # String | 
webaide_type = 'webaide_type_example' # String | 
webaide_id = 'webaide_id_example' # String | 
entry_id = 'entry_id_example' # String | 
opts = { 
  body: Luxsci::WebaideIdEntryIdBody.new, # WebaideIdEntryIdBody | 
}

begin
  result = api_instance.update_web_aide_entry(username, webaide_type, webaide_id, entry_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling WebAidesApi->update_web_aide_entry: #{e}"
end
```

## File Attachments
The SDK's [EmailSendingApi.sendEmail](docs/EmailSendingApi.md#sendemail) and [EmailSendingApi.SendSecureEmailOrSecureText](docs/EmailSendingApi.md#sendsecureemailorsecuretext) methods include an optional `attachments` field similar to what is required by the REST API. For the SDK however, you only need to provide a string path that points to the location of the file on local disk you would like to attach.

## Documentation for API Endpoints

All URIs are relative to *https://rest.luxsci.com/perl/api/v2* unless a custom API hostname is specfied. To add a custom hostname, set the `host` configuration
```ruby
require 'luxsci'

Luxsci.configure do |config|
  config.private_token = 'SECRET_TOKEN'
  config.public_token = 'PUBLIC_TOKEN'
  config.host = 'example.com' # SDK will use https://example.com/perl/api/v2
end

api_instance = Luxsci::UsersApi.new
username = 'username_example' # String | 
opts = { 
}
begin
  result = api_instance.get_user(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->get_user: #{e}"
end

```


Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*Luxsci::AuthenticationApi* | [**authentication**](docs/AuthenticationApi.md#authentication) | **POST** /auth | 
*Luxsci::AuthenticationApi* | [**revoke_authentication**](docs/AuthenticationApi.md#revoke_authentication) | **DELETE** /auth | 
*Luxsci::ContentLibraryApi* | [**create_content_library_directory**](docs/ContentLibraryApi.md#create_content_library_directory) | **PUT** /user/{username}/content_library/{directory} | 
*Luxsci::ContentLibraryApi* | [**delete_content_library_directory**](docs/ContentLibraryApi.md#delete_content_library_directory) | **DELETE** /user/{username}/content_library/{directory} | 
*Luxsci::ContentLibraryApi* | [**delete_content_library_file**](docs/ContentLibraryApi.md#delete_content_library_file) | **DELETE** /user/{username}/content_library/{file_path} | 
*Luxsci::ContentLibraryApi* | [**get_content_library_directory**](docs/ContentLibraryApi.md#get_content_library_directory) | **GET** /user/{username}/content_library/{directory} | 
*Luxsci::ContentLibraryApi* | [**get_content_library_file**](docs/ContentLibraryApi.md#get_content_library_file) | **GET** /user/{username}/content_library/{file_path} | 
*Luxsci::ContentLibraryApi* | [**upload_content_library_file**](docs/ContentLibraryApi.md#upload_content_library_file) | **PUT** /user/{username}/content_library/{file_path} | 
*Luxsci::DomainsApi* | [**create_domain**](docs/DomainsApi.md#create_domain) | **POST** /account/{accountId}/domains | 
*Luxsci::DomainsApi* | [**delete_domain**](docs/DomainsApi.md#delete_domain) | **DELETE** /account/{accountId}/domains/{domainName} | 
*Luxsci::DomainsApi* | [**get_domain_details**](docs/DomainsApi.md#get_domain_details) | **GET** /account/{accountId}/domains/{domainName} | 
*Luxsci::DomainsApi* | [**get_domains_report**](docs/DomainsApi.md#get_domains_report) | **GET** /account/{accountId}/domains | 
*Luxsci::DomainsApi* | [**update_domain**](docs/DomainsApi.md#update_domain) | **PUT** /account/{accountId}/domains/{domainName} | 
*Luxsci::EmailApi* | [**create_custom_bounce_domain**](docs/EmailApi.md#create_custom_bounce_domain) | **POST** /account/{accountId}/bounce_domain | 
*Luxsci::EmailApi* | [**create_dkim**](docs/EmailApi.md#create_dkim) | **POST** /account/{accountId}/dkim | 
*Luxsci::EmailApi* | [**delete_dkim**](docs/EmailApi.md#delete_dkim) | **DELETE** /account/{accountId}/dkim/{domainName} | 
*Luxsci::EmailApi* | [**delete_email_auto_responder**](docs/EmailApi.md#delete_email_auto_responder) | **DELETE** /user/{username}/email/ar/{id} | 
*Luxsci::EmailApi* | [**get_dkim_details**](docs/EmailApi.md#get_dkim_details) | **GET** /account/{accountId}/dkim/{domainName} | 
*Luxsci::EmailApi* | [**get_dkim_report**](docs/EmailApi.md#get_dkim_report) | **GET** /account/{accountId}/dkim | 
*Luxsci::EmailApi* | [**get_email_auto_responders**](docs/EmailApi.md#get_email_auto_responders) | **GET** /user/{username}/email/ar | 
*Luxsci::EmailApi* | [**new_email_auto_responder**](docs/EmailApi.md#new_email_auto_responder) | **POST** /user/{username}/email/ar | 
*Luxsci::EmailApi* | [**retrieve_secure_line_recipient_list_encryption_data**](docs/EmailApi.md#retrieve_secure_line_recipient_list_encryption_data) | **POST** /user/{username}/email/compose/secureline/recipients | 
*Luxsci::EmailApi* | [**update_email_forwarding**](docs/EmailApi.md#update_email_forwarding) | **PUT** /user/{username}/email/forwarding | 
*Luxsci::EmailAliasesApi* | [**create_alias**](docs/EmailAliasesApi.md#create_alias) | **POST** /account/{accountId}/aliases | 
*Luxsci::EmailAliasesApi* | [**delete_alias**](docs/EmailAliasesApi.md#delete_alias) | **DELETE** /account/{accountId}/aliases/{aliasAddress} | 
*Luxsci::EmailAliasesApi* | [**get_alias_details**](docs/EmailAliasesApi.md#get_alias_details) | **GET** /account/{accountId}/aliases/{aliasAddress} | 
*Luxsci::EmailAliasesApi* | [**get_aliases_report**](docs/EmailAliasesApi.md#get_aliases_report) | **GET** /account/{accountId}/aliases | 
*Luxsci::EmailAliasesApi* | [**update_alias**](docs/EmailAliasesApi.md#update_alias) | **PUT** /account/{accountId}/aliases/{aliasAddress} | 
*Luxsci::EmailSendingApi* | [**create_account_suppression**](docs/EmailSendingApi.md#create_account_suppression) | **PUT** /account/{accountId}/suppression/ | 
*Luxsci::EmailSendingApi* | [**create_custom_field**](docs/EmailSendingApi.md#create_custom_field) | **PUT** /user/{username}/fields | 
*Luxsci::EmailSendingApi* | [**create_email_content_tag**](docs/EmailSendingApi.md#create_email_content_tag) | **PUT** /user/{username}/content_tags | 
*Luxsci::EmailSendingApi* | [**create_email_template**](docs/EmailSendingApi.md#create_email_template) | **PUT** /user/{username}/templates | 
*Luxsci::EmailSendingApi* | [**create_email_template_group**](docs/EmailSendingApi.md#create_email_template_group) | **PUT** /user/{username}/template_group/{template_group_id} | 
*Luxsci::EmailSendingApi* | [**create_user_suppression**](docs/EmailSendingApi.md#create_user_suppression) | **PUT** /user/{username}/suppression/ | 
*Luxsci::EmailSendingApi* | [**delete_account_suppression**](docs/EmailSendingApi.md#delete_account_suppression) | **DELETE** /account/{accountId}/suppression/{email} | 
*Luxsci::EmailSendingApi* | [**delete_email_content_tag**](docs/EmailSendingApi.md#delete_email_content_tag) | **DELETE** /user/{username}/content_tags/{tag_id} | 
*Luxsci::EmailSendingApi* | [**delete_email_template**](docs/EmailSendingApi.md#delete_email_template) | **DELETE** /user/{username}/template/{template_id} | 
*Luxsci::EmailSendingApi* | [**delete_email_template_group**](docs/EmailSendingApi.md#delete_email_template_group) | **DELETE** /user/{username}/template_group/{template_group_id} | 
*Luxsci::EmailSendingApi* | [**delete_user_suppression**](docs/EmailSendingApi.md#delete_user_suppression) | **DELETE** /user/{username}/suppression/{email} | 
*Luxsci::EmailSendingApi* | [**get_account_suppression**](docs/EmailSendingApi.md#get_account_suppression) | **GET** /account/{accountId}/suppression/{email} | 
*Luxsci::EmailSendingApi* | [**get_account_suppression_list**](docs/EmailSendingApi.md#get_account_suppression_list) | **GET** /account/{accountId}/suppression/ | 
*Luxsci::EmailSendingApi* | [**get_custom_fields**](docs/EmailSendingApi.md#get_custom_fields) | **GET** /user/{username}/fields | 
*Luxsci::EmailSendingApi* | [**get_domain_smtp_tls_capability**](docs/EmailSendingApi.md#get_domain_smtp_tls_capability) | **GET** /user/{username}/email/compose/secureline/tls/{domain} | 
*Luxsci::EmailSendingApi* | [**get_email_content_tag**](docs/EmailSendingApi.md#get_email_content_tag) | **GET** /user/{username}/content_tags/{tag_id} | 
*Luxsci::EmailSendingApi* | [**get_email_content_tag_list**](docs/EmailSendingApi.md#get_email_content_tag_list) | **GET** /user/{username}/content_tags | 
*Luxsci::EmailSendingApi* | [**get_email_template**](docs/EmailSendingApi.md#get_email_template) | **GET** /user/{username}/template/{template_id} | 
*Luxsci::EmailSendingApi* | [**get_email_template_groups**](docs/EmailSendingApi.md#get_email_template_groups) | **GET** /user/{username}/template_groups | 
*Luxsci::EmailSendingApi* | [**get_email_template_list**](docs/EmailSendingApi.md#get_email_template_list) | **GET** /user/{username}/templates | 
*Luxsci::EmailSendingApi* | [**get_user_suppression**](docs/EmailSendingApi.md#get_user_suppression) | **GET** /user/{username}/suppression/{email} | 
*Luxsci::EmailSendingApi* | [**get_user_suppression_list**](docs/EmailSendingApi.md#get_user_suppression_list) | **GET** /user/{username}/suppression/ | 
*Luxsci::EmailSendingApi* | [**send_email**](docs/EmailSendingApi.md#send_email) | **POST** /user/{username}/email/send | 
*Luxsci::EmailSendingApi* | [**send_secure_email_or_secure_text**](docs/EmailSendingApi.md#send_secure_email_or_secure_text) | **POST** /user/{username}/email/compose/secureline/send | 
*Luxsci::EmailSendingApi* | [**update_email_content_tag**](docs/EmailSendingApi.md#update_email_content_tag) | **POST** /user/{username}/content_tags/{tag_id} | 
*Luxsci::EmailSendingApi* | [**update_email_template**](docs/EmailSendingApi.md#update_email_template) | **POST** /user/{username}/template/{template_id} | 
*Luxsci::EmailSendingApi* | [**update_email_template_group**](docs/EmailSendingApi.md#update_email_template_group) | **POST** /user/{username}/template_group/{template_group_id} | 
*Luxsci::MarketingApi* | [**add_marketing_campaign**](docs/MarketingApi.md#add_marketing_campaign) | **POST** /account/{accountId}/marketing/addCampaign | 
*Luxsci::MarketingApi* | [**add_marketing_contact**](docs/MarketingApi.md#add_marketing_contact) | **POST** /account/{accountId}/marketing/addContact | 
*Luxsci::MarketingApi* | [**add_marketing_contacts**](docs/MarketingApi.md#add_marketing_contacts) | **POST** /account/{accountId}/marketing/addContacts | 
*Luxsci::MarketingApi* | [**add_marketing_list**](docs/MarketingApi.md#add_marketing_list) | **POST** /account/{accountId}/marketing/addList | 
*Luxsci::MarketingApi* | [**add_new_marketing_suppression**](docs/MarketingApi.md#add_new_marketing_suppression) | **POST** /account/{accountId}/marketing/suppress | 
*Luxsci::MarketingApi* | [**delete_marketing_campaign**](docs/MarketingApi.md#delete_marketing_campaign) | **DELETE** /account/{accountId}/marketing/deleteCampaign/{id} | 
*Luxsci::MarketingApi* | [**delete_marketing_contact_by_id**](docs/MarketingApi.md#delete_marketing_contact_by_id) | **DELETE** /account/{accountId}/marketing/deleteContact/{id} | 
*Luxsci::MarketingApi* | [**delete_marketing_list**](docs/MarketingApi.md#delete_marketing_list) | **DELETE** /account/{accountId}/marketing/deleteList/{id} | 
*Luxsci::MarketingApi* | [**delete_marketing_list_group**](docs/MarketingApi.md#delete_marketing_list_group) | **DELETE** /account/{accountId}/deleteListGroup/{id} | 
*Luxsci::MarketingApi* | [**delete_marketing_suppression**](docs/MarketingApi.md#delete_marketing_suppression) | **DELETE** /account/{accountId}/marketing/deleteSuppressed/{type} | 
*Luxsci::MarketingApi* | [**get_marketing_campaign_bounced_statistics**](docs/MarketingApi.md#get_marketing_campaign_bounced_statistics) | **GET** /account/{accountId}/marketing/getCampaignStatsBounced/{schedule_id} | 
*Luxsci::MarketingApi* | [**get_marketing_campaign_clicked_statistics**](docs/MarketingApi.md#get_marketing_campaign_clicked_statistics) | **GET** /account/{accountId}/marketing/getCampaignStatsClicked/{schedule_id} | 
*Luxsci::MarketingApi* | [**get_marketing_campaign_groups**](docs/MarketingApi.md#get_marketing_campaign_groups) | **GET** /account/{accountId}/marketing/getMarketingCampaignGroups | 
*Luxsci::MarketingApi* | [**get_marketing_campaign_opened_statistics**](docs/MarketingApi.md#get_marketing_campaign_opened_statistics) | **GET** /account/{accountId}/marketing/getCampaignStatsOpened/{schedule_id} | 
*Luxsci::MarketingApi* | [**get_marketing_campaign_statistics_summary**](docs/MarketingApi.md#get_marketing_campaign_statistics_summary) | **GET** /account/{accountId}/marketing/getCampaignStatsSummary/{schedule_id} | 
*Luxsci::MarketingApi* | [**get_marketing_campaign_unsubscribed_statistics**](docs/MarketingApi.md#get_marketing_campaign_unsubscribed_statistics) | **GET** /account/{accountId}/marketing/getCampaignStatsUnsubscribed/{schedule_id} | 
*Luxsci::MarketingApi* | [**get_marketing_campaigns**](docs/MarketingApi.md#get_marketing_campaigns) | **GET** /account/{accountId}/marketing/getCampaigns | 
*Luxsci::MarketingApi* | [**get_marketing_contact_by_id**](docs/MarketingApi.md#get_marketing_contact_by_id) | **GET** /account/{accountId}/marketing/getContact/{id} | 
*Luxsci::MarketingApi* | [**get_marketing_contacts**](docs/MarketingApi.md#get_marketing_contacts) | **GET** /account/{accountId}/marketing/getContacts | 
*Luxsci::MarketingApi* | [**get_marketing_list_groups**](docs/MarketingApi.md#get_marketing_list_groups) | **GET** /account/{accountId}/marketing/getMarketingListGroups | 
*Luxsci::MarketingApi* | [**get_marketing_lists**](docs/MarketingApi.md#get_marketing_lists) | **GET** /account/{accountId}/marketing/getLists | 
*Luxsci::MarketingApi* | [**get_marketing_scheduled_campaigns**](docs/MarketingApi.md#get_marketing_scheduled_campaigns) | **GET** /account/{accountId}/marketing/getMarketingScheduledCampaigns | 
*Luxsci::MarketingApi* | [**get_marketing_suppressions**](docs/MarketingApi.md#get_marketing_suppressions) | **GET** /account/{accountId}/marketing/getSuppressed | 
*Luxsci::MarketingApi* | [**mark_contact_as_unsubscribed**](docs/MarketingApi.md#mark_contact_as_unsubscribed) | **PUT** /account/{accountId}/markAsUnsubscribed/{id} | 
*Luxsci::MarketingApi* | [**schedule_marketing_campaign**](docs/MarketingApi.md#schedule_marketing_campaign) | **POST** /account/{accountId}/marketing/campaignSchedule | 
*Luxsci::MarketingApi* | [**update_marketing_campaign**](docs/MarketingApi.md#update_marketing_campaign) | **PUT** /account/{accountId}/marketing/updateCampaign/{id} | 
*Luxsci::MarketingApi* | [**update_marketing_contact_by_email**](docs/MarketingApi.md#update_marketing_contact_by_email) | **PUT** /account/{accountId}/marketing/updateContact/{email} | 
*Luxsci::MarketingApi* | [**update_marketing_contact_by_id**](docs/MarketingApi.md#update_marketing_contact_by_id) | **PUT** /account/{accountId}/marketing/updateContact/{id} | 
*Luxsci::MarketingApi* | [**update_marketing_list**](docs/MarketingApi.md#update_marketing_list) | **PUT** /account/{accountId}/marketing/updateList/{id} | 
*Luxsci::Marketing3Api* | [**add_campaign**](docs/Marketing3Api.md#add_campaign) | **POST** /user/{username}/marketing/campaigns | 
*Luxsci::Marketing3Api* | [**add_contact**](docs/Marketing3Api.md#add_contact) | **POST** /user/{username}/marketing/contact | 
*Luxsci::Marketing3Api* | [**add_contacts**](docs/Marketing3Api.md#add_contacts) | **POST** /user/{username}/marketing/contacts | 
*Luxsci::Marketing3Api* | [**add_list**](docs/Marketing3Api.md#add_list) | **POST** /user/{username}/marketing/list | 
*Luxsci::Marketing3Api* | [**add_list_group**](docs/Marketing3Api.md#add_list_group) | **PUT** /user/{username}/marketing/list_group/{list_group_id} | 
*Luxsci::Marketing3Api* | [**delete_campaign**](docs/Marketing3Api.md#delete_campaign) | **DELETE** /user/{username}/marketing/campaign/{campaign_id} | 
*Luxsci::Marketing3Api* | [**delete_contact**](docs/Marketing3Api.md#delete_contact) | **DELETE** /user/{username}/marketing/contact/{contact_id} | 
*Luxsci::Marketing3Api* | [**delete_list**](docs/Marketing3Api.md#delete_list) | **DELETE** /user/{username}/marketing/list/{list_id} | 
*Luxsci::Marketing3Api* | [**delete_list_group**](docs/Marketing3Api.md#delete_list_group) | **DELETE** /user/{username}/marketing/list_group/{list_group_id} | 
*Luxsci::Marketing3Api* | [**get_campaign**](docs/Marketing3Api.md#get_campaign) | **GET** /user/{username}/marketing/campaign/{campaign_id} | 
*Luxsci::Marketing3Api* | [**get_campaigns**](docs/Marketing3Api.md#get_campaigns) | **GET** /user/{username}/marketing/campaigns | 
*Luxsci::Marketing3Api* | [**get_contact**](docs/Marketing3Api.md#get_contact) | **GET** /user/{username}/marketing/contact/{contact_id} | 
*Luxsci::Marketing3Api* | [**get_contacts**](docs/Marketing3Api.md#get_contacts) | **GET** /user/{username}/marketing/contacts | 
*Luxsci::Marketing3Api* | [**get_list**](docs/Marketing3Api.md#get_list) | **GET** /user/{username}/marketing/list/{list_id} | 
*Luxsci::Marketing3Api* | [**get_list_groups**](docs/Marketing3Api.md#get_list_groups) | **GET** /user/{username}/marketing/list_groups | 
*Luxsci::Marketing3Api* | [**get_lists**](docs/Marketing3Api.md#get_lists) | **GET** /user/{username}/marketing/lists | 
*Luxsci::Marketing3Api* | [**get_report_bounced**](docs/Marketing3Api.md#get_report_bounced) | **GET** /user/{username}/marketing/report/bounced | 
*Luxsci::Marketing3Api* | [**get_report_clicked**](docs/Marketing3Api.md#get_report_clicked) | **GET** /user/{username}/marketing/report/clicked | 
*Luxsci::Marketing3Api* | [**get_report_complaints**](docs/Marketing3Api.md#get_report_complaints) | **GET** /user/{username}/marketing/report/complaints | 
*Luxsci::Marketing3Api* | [**get_report_logs**](docs/Marketing3Api.md#get_report_logs) | **GET** /user/{username}/marketing/report/logs | 
*Luxsci::Marketing3Api* | [**get_report_opened**](docs/Marketing3Api.md#get_report_opened) | **GET** /user/{username}/marketing/report/opened | 
*Luxsci::Marketing3Api* | [**get_report_unsubscribed**](docs/Marketing3Api.md#get_report_unsubscribed) | **GET** /user/{username}/marketing/report/unsubscribed | 
*Luxsci::Marketing3Api* | [**get_report_urls**](docs/Marketing3Api.md#get_report_urls) | **GET** /user/{username}/marketing/report/urls | 
*Luxsci::Marketing3Api* | [**update_campaign**](docs/Marketing3Api.md#update_campaign) | **PUT** /user/{username}/marketing/campaign/{campaign_id} | 
*Luxsci::Marketing3Api* | [**update_contact**](docs/Marketing3Api.md#update_contact) | **PUT** /user/{username}/marketing/contact/{contact_id} | 
*Luxsci::Marketing3Api* | [**update_list**](docs/Marketing3Api.md#update_list) | **PUT** /user/{username}/marketing/list/{list_id} | 
*Luxsci::Marketing3Api* | [**update_list_group**](docs/Marketing3Api.md#update_list_group) | **POST** /user/{username}/marketing/list_group/{list_group_id} | 
*Luxsci::ReportsApi* | [**get_account_job**](docs/ReportsApi.md#get_account_job) | **GET** /account/{accountId}/job/{job_id} | 
*Luxsci::ReportsApi* | [**get_account_jobs**](docs/ReportsApi.md#get_account_jobs) | **GET** /account/{accountId}/jobs | 
*Luxsci::ReportsApi* | [**get_account_suppression_report**](docs/ReportsApi.md#get_account_suppression_report) | **GET** /account/{accountId}/suppression_v2/ | 
*Luxsci::ReportsApi* | [**get_account_suppression_summary_report**](docs/ReportsApi.md#get_account_suppression_summary_report) | **GET** /account/{accountId}/suppression_count/ | 
*Luxsci::ReportsApi* | [**get_email_feed_back_loops_report_account**](docs/ReportsApi.md#get_email_feed_back_loops_report_account) | **GET** /account/{accountId}/report/email/fbl | 
*Luxsci::ReportsApi* | [**get_email_feed_back_loops_summary_report_account**](docs/ReportsApi.md#get_email_feed_back_loops_summary_report_account) | **GET** /account/{accountId}/report/email/fbl_count | 
*Luxsci::ReportsApi* | [**get_email_smtp_click_report_account**](docs/ReportsApi.md#get_email_smtp_click_report_account) | **GET** /account/{accountId}/report/email/smtp/clicks | 
*Luxsci::ReportsApi* | [**get_email_smtp_click_summary_report_account**](docs/ReportsApi.md#get_email_smtp_click_summary_report_account) | **GET** /account/{accountId}/report/email/smtp/clicks_count | 
*Luxsci::ReportsApi* | [**get_email_smtp_delivery_status_report_account**](docs/ReportsApi.md#get_email_smtp_delivery_status_report_account) | **GET** /account/{accountId}/report/email/smtp/delivery | 
*Luxsci::ReportsApi* | [**get_email_smtp_delivery_status_summary_report_account**](docs/ReportsApi.md#get_email_smtp_delivery_status_summary_report_account) | **GET** /account/{accountId}/report/email/smtp/delivery_count | 
*Luxsci::ReportsApi* | [**get_email_smtp_open_report_account**](docs/ReportsApi.md#get_email_smtp_open_report_account) | **GET** /account/{accountId}/report/email/smtp/opens | 
*Luxsci::ReportsApi* | [**get_email_smtp_open_summary_report_account**](docs/ReportsApi.md#get_email_smtp_open_summary_report_account) | **GET** /account/{accountId}/report/email/smtp/opens_count | 
*Luxsci::ReportsApi* | [**get_email_smtp_sent_report_account**](docs/ReportsApi.md#get_email_smtp_sent_report_account) | **GET** /account/{accountId}/report/email/smtp/sent | 
*Luxsci::ReportsApi* | [**get_email_smtp_temp_fail_report_account**](docs/ReportsApi.md#get_email_smtp_temp_fail_report_account) | **GET** /account/{accountId}/report/email/smtp/temp_fail | 
*Luxsci::ReportsApi* | [**get_email_web_mail_click_report_account**](docs/ReportsApi.md#get_email_web_mail_click_report_account) | **GET** /account/{accountId}/report/email/webmail/clicks | 
*Luxsci::ReportsApi* | [**get_email_web_mail_delivery_status_report_account**](docs/ReportsApi.md#get_email_web_mail_delivery_status_report_account) | **GET** /account/{accountId}/report/email/webmail/delivery | 
*Luxsci::ReportsApi* | [**get_email_web_mail_open_report_account**](docs/ReportsApi.md#get_email_web_mail_open_report_account) | **GET** /account/{accountId}/report/email/webmail/opens | 
*Luxsci::ReportsApi* | [**get_email_web_mail_sent_report_account**](docs/ReportsApi.md#get_email_web_mail_sent_report_account) | **GET** /account/{accountId}/report/email/webmail/sent | 
*Luxsci::ReportsApi* | [**get_smtp_login_failure_report_account**](docs/ReportsApi.md#get_smtp_login_failure_report_account) | **GET** /account/{accountId}/report/login_fail/smtp | 
*Luxsci::SecureFormApi* | [**delete_secure_form_database_file**](docs/SecureFormApi.md#delete_secure_form_database_file) | **DELETE** /account/{accountId}/secureforms/{formID}/db/{rowIndex}/file/{fileIndex} | 
*Luxsci::SecureFormApi* | [**delete_secure_form_database_row**](docs/SecureFormApi.md#delete_secure_form_database_row) | **DELETE** /account/{accountId}/secureforms/{formID}/db/rows/{index} | 
*Luxsci::SecureFormApi* | [**get_secure_form**](docs/SecureFormApi.md#get_secure_form) | **GET** /account/{accountId}/secureforms/{formID} | 
*Luxsci::SecureFormApi* | [**get_secure_form_database_file**](docs/SecureFormApi.md#get_secure_form_database_file) | **GET** /account/{accountId}/secureforms/{formID}/db/{rowIndex}/file/{fileIndex} | 
*Luxsci::SecureFormApi* | [**get_secure_form_database_posts**](docs/SecureFormApi.md#get_secure_form_database_posts) | **GET** /account/{accountId}/secureforms/{formID}/db | 
*Luxsci::SecureFormApi* | [**get_secure_form_database_row**](docs/SecureFormApi.md#get_secure_form_database_row) | **GET** /account/{accountId}/secureforms/{formID}/db/rows/{index} | 
*Luxsci::SecureFormApi* | [**get_secure_form_database_rows**](docs/SecureFormApi.md#get_secure_form_database_rows) | **GET** /account/{accountId}/secureforms/{formID}/db/rows | 
*Luxsci::SecureFormApi* | [**get_secure_form_list**](docs/SecureFormApi.md#get_secure_form_list) | **GET** /account/{accountId}/secureforms | 
*Luxsci::SecureSendApi* | [**change_secure_send_user_password**](docs/SecureSendApi.md#change_secure_send_user_password) | **PUT** /account/{accountId}/pl/namespaces/{namespaceId}/users/{username}/password | 
*Luxsci::SecureSendApi* | [**create_or_update_secure_send_user**](docs/SecureSendApi.md#create_or_update_secure_send_user) | **PUT** /account/{accountId}/pl/namespaces/{namespaceId}/users/{username} | 
*Luxsci::SecureSendApi* | [**get_secure_send_user_list**](docs/SecureSendApi.md#get_secure_send_user_list) | **GET** /account/{accountId}/pl/namespaces/{namespaceId}/users | 
*Luxsci::SecureSendApi* | [**get_secure_send_user_single_sign_on_link**](docs/SecureSendApi.md#get_secure_send_user_single_sign_on_link) | **GET** /account/{accountId}/pl/namespaces/{namespaceId}/users/{username}/password | 
*Luxsci::ServersApi* | [**get_server_status**](docs/ServersApi.md#get_server_status) | **GET** /account/{accountId}/server/{serverId} | 
*Luxsci::ServersApi* | [**get_servers**](docs/ServersApi.md#get_servers) | **GET** /account/{accountId}/servers | 
*Luxsci::ServersApi* | [**server_empty_all_email_queues**](docs/ServersApi.md#server_empty_all_email_queues) | **DELETE** /account/{accountId}/server/{serverId}/sending_queues/all | 
*Luxsci::ServersApi* | [**server_empty_email_queues**](docs/ServersApi.md#server_empty_email_queues) | **DELETE** /account/{accountId}/server/{serverId}/sending_queues | 
*Luxsci::ServersApi* | [**set_server_sendng_rate**](docs/ServersApi.md#set_server_sendng_rate) | **POST** /account/{accountId}/server/{serverId}/sending_rate | 
*Luxsci::UserReportsApi* | [**get_email_feed_back_loops_report_user**](docs/UserReportsApi.md#get_email_feed_back_loops_report_user) | **GET** /user/{username}/report/email/fbl | 
*Luxsci::UserReportsApi* | [**get_email_feed_back_loops_summary_report_user**](docs/UserReportsApi.md#get_email_feed_back_loops_summary_report_user) | **GET** /user/{username}/report/email/fbl_count | 
*Luxsci::UserReportsApi* | [**get_email_smtp_click_report_user**](docs/UserReportsApi.md#get_email_smtp_click_report_user) | **GET** /user/{username}/report/email/smtp/clicks | 
*Luxsci::UserReportsApi* | [**get_email_smtp_click_summary_report_user**](docs/UserReportsApi.md#get_email_smtp_click_summary_report_user) | **GET** /user/{username}/report/email/smtp/clicks_count | 
*Luxsci::UserReportsApi* | [**get_email_smtp_delivery_status_report_user**](docs/UserReportsApi.md#get_email_smtp_delivery_status_report_user) | **GET** /user/{username}/report/email/smtp/delivery | 
*Luxsci::UserReportsApi* | [**get_email_smtp_delivery_status_summary_report_user**](docs/UserReportsApi.md#get_email_smtp_delivery_status_summary_report_user) | **GET** /user/{username}/report/email/smtp/delivery_count | 
*Luxsci::UserReportsApi* | [**get_email_smtp_login_failure_report_user**](docs/UserReportsApi.md#get_email_smtp_login_failure_report_user) | **GET** /user/{username}/report/login_fail/smtp | 
*Luxsci::UserReportsApi* | [**get_email_smtp_open_report_user**](docs/UserReportsApi.md#get_email_smtp_open_report_user) | **GET** /user/{username}/report/email/smtp/opens | 
*Luxsci::UserReportsApi* | [**get_email_smtp_open_summary_report_user**](docs/UserReportsApi.md#get_email_smtp_open_summary_report_user) | **GET** /user/{username}/report/email/smtp/opens_count | 
*Luxsci::UserReportsApi* | [**get_email_smtp_sent_report_user**](docs/UserReportsApi.md#get_email_smtp_sent_report_user) | **GET** /user/{username}/report/email/smtp/sent | 
*Luxsci::UserReportsApi* | [**get_email_smtp_temp_fail_report_user**](docs/UserReportsApi.md#get_email_smtp_temp_fail_report_user) | **GET** /user/{username}/report/email/smtp/temp_fail | 
*Luxsci::UserReportsApi* | [**get_email_web_mail_click_report_user**](docs/UserReportsApi.md#get_email_web_mail_click_report_user) | **GET** /user/{username}/report/email/webmail/clicks | 
*Luxsci::UserReportsApi* | [**get_email_web_mail_delivery_status_report_user**](docs/UserReportsApi.md#get_email_web_mail_delivery_status_report_user) | **GET** /user/{username}/report/email/webmail/delivery | 
*Luxsci::UserReportsApi* | [**get_email_web_mail_open_report_user**](docs/UserReportsApi.md#get_email_web_mail_open_report_user) | **GET** /user/{username}/report/email/webmail/opens | 
*Luxsci::UserReportsApi* | [**get_email_web_mail_sent_report_user**](docs/UserReportsApi.md#get_email_web_mail_sent_report_user) | **GET** /user/{username}/report/email/webmail/sent | 
*Luxsci::UserReportsApi* | [**get_user_job**](docs/UserReportsApi.md#get_user_job) | **GET** /user/{username}/job/{job_id} | 
*Luxsci::UserReportsApi* | [**get_user_jobs**](docs/UserReportsApi.md#get_user_jobs) | **GET** /user/{username}/jobs | 
*Luxsci::UserReportsApi* | [**get_user_suppression_report**](docs/UserReportsApi.md#get_user_suppression_report) | **GET** /user/{username}/suppression_v2/ | 
*Luxsci::UserReportsApi* | [**get_user_suppression_summary_report**](docs/UserReportsApi.md#get_user_suppression_summary_report) | **GET** /user/{username}/suppression_count/ | 
*Luxsci::UsersApi* | [**change_user_password**](docs/UsersApi.md#change_user_password) | **PUT** /user/{username}/password | 
*Luxsci::UsersApi* | [**create_app_specific_password**](docs/UsersApi.md#create_app_specific_password) | **POST** /user/{username}/app-password/{suffix} | 
*Luxsci::UsersApi* | [**create_user**](docs/UsersApi.md#create_user) | **POST** /account/{accountId}/users | 
*Luxsci::UsersApi* | [**delete_app_specific_password**](docs/UsersApi.md#delete_app_specific_password) | **DELETE** /user/{username}/app-password/{suffix} | 
*Luxsci::UsersApi* | [**delete_user**](docs/UsersApi.md#delete_user) | **DELETE** /account/{accountId}/users/{username} | 
*Luxsci::UsersApi* | [**get_time_zones_list**](docs/UsersApi.md#get_time_zones_list) | **GET** /user/{username}/settings/timezones | 
*Luxsci::UsersApi* | [**get_user**](docs/UsersApi.md#get_user) | **GET** /user/{username} | 
*Luxsci::UsersApi* | [**get_user_branding_information**](docs/UsersApi.md#get_user_branding_information) | **GET** /user/{username}/branding | 
*Luxsci::UsersApi* | [**get_user_profile**](docs/UsersApi.md#get_user_profile) | **GET** /user/{username}/profile | 
*Luxsci::UsersApi* | [**get_user_report**](docs/UsersApi.md#get_user_report) | **GET** /account/{accountId}/users | 
*Luxsci::UsersApi* | [**get_user_report2**](docs/UsersApi.md#get_user_report2) | **GET** /account/{accountId}/users/report | 
*Luxsci::UsersApi* | [**get_user_settings**](docs/UsersApi.md#get_user_settings) | **GET** /user/{username}/settings | 
*Luxsci::UsersApi* | [**get_user_single_sign_on_login_url**](docs/UsersApi.md#get_user_single_sign_on_login_url) | **GET** /user/{username}/password | 
*Luxsci::UsersApi* | [**get_user_summary_report**](docs/UsersApi.md#get_user_summary_report) | **GET** /account/{accountId}/users/report_count | 
*Luxsci::UsersApi* | [**list_all_app_specific_password**](docs/UsersApi.md#list_all_app_specific_password) | **GET** /user/{username}/app-password | 
*Luxsci::UsersApi* | [**list_app_specific_passwords**](docs/UsersApi.md#list_app_specific_passwords) | **GET** /user/{username}/app-password/{suffix} | 
*Luxsci::UsersApi* | [**rename_user**](docs/UsersApi.md#rename_user) | **POST** /account/{accountId}/users/{username}/rename | 
*Luxsci::UsersApi* | [**update_user**](docs/UsersApi.md#update_user) | **PUT** /user/{username} | 
*Luxsci::UsersApi* | [**update_user_profile**](docs/UsersApi.md#update_user_profile) | **PUT** /user/{username}/profile | 
*Luxsci::UsersApi* | [**update_user_settings**](docs/UsersApi.md#update_user_settings) | **PUT** /account/{accountId}/users/{username} | 
*Luxsci::WebAidesApi* | [**add_update_web_aide_entries**](docs/WebAidesApi.md#add_update_web_aide_entries) | **POST** /user/{username}/webaides/{webaide_type}/{webaide_id}/entries/import | 
*Luxsci::WebAidesApi* | [**delete_web_aide**](docs/WebAidesApi.md#delete_web_aide) | **DELETE** /user/{username}/webaides/{webaide_type}/{webaide_id} | 
*Luxsci::WebAidesApi* | [**delete_web_aide_entries**](docs/WebAidesApi.md#delete_web_aide_entries) | **POST** /user/{username}/webaides/{webaide_type}/{webaide_id}/entries/delete | 
*Luxsci::WebAidesApi* | [**delete_web_aide_entry**](docs/WebAidesApi.md#delete_web_aide_entry) | **DELETE** /user/{username}/webaides/{webaide_type}/{webaide_id}/{entry_id} | 
*Luxsci::WebAidesApi* | [**get_calendar_entries_date_range**](docs/WebAidesApi.md#get_calendar_entries_date_range) | **GET** /user/{username}/webaides/calendar/{webaide_id}/entries/date_range | 
*Luxsci::WebAidesApi* | [**get_web_aide**](docs/WebAidesApi.md#get_web_aide) | **GET** /user/{username}/webaides/{webaide_type}/{webaide_id} | 
*Luxsci::WebAidesApi* | [**get_web_aide_changes**](docs/WebAidesApi.md#get_web_aide_changes) | **GET** /user/{username}/webaides/{webaide_type}/{webaide_id}/entries/changes | 
*Luxsci::WebAidesApi* | [**get_web_aide_entries**](docs/WebAidesApi.md#get_web_aide_entries) | **GET** /user/{username}/webaides/{webaide_type}/{webaide_id}/entries | 
*Luxsci::WebAidesApi* | [**get_web_aide_entry**](docs/WebAidesApi.md#get_web_aide_entry) | **GET** /user/{username}/webaides/{webaide_type}/{webaide_id}/{entry_id} | 
*Luxsci::WebAidesApi* | [**get_web_aides**](docs/WebAidesApi.md#get_web_aides) | **GET** /user/{username}/webaides/{webaide_type} | 
*Luxsci::WebAidesApi* | [**new_web_aide**](docs/WebAidesApi.md#new_web_aide) | **POST** /user/{username}/webaides/{webaide_type} | 
*Luxsci::WebAidesApi* | [**new_web_aide_entry**](docs/WebAidesApi.md#new_web_aide_entry) | **POST** /user/{username}/webaides/{webaide_type}/{webaide_id} | 
*Luxsci::WebAidesApi* | [**update_web_aide_entry**](docs/WebAidesApi.md#update_web_aide_entry) | **PUT** /user/{username}/webaides/{webaide_type}/{webaide_id}/{entry_id} | 

## Documentation for Models

 - [Luxsci::AccountIdAliasesBody](docs/AccountIdAliasesBody.md)
 - [Luxsci::AccountIdBounceDomainBody](docs/AccountIdBounceDomainBody.md)
 - [Luxsci::AccountIdDkimBody](docs/AccountIdDkimBody.md)
 - [Luxsci::AccountIdDomainsBody](docs/AccountIdDomainsBody.md)
 - [Luxsci::AccountIdUsersBody](docs/AccountIdUsersBody.md)
 - [Luxsci::AccountaccountIdaliasesAliases](docs/AccountaccountIdaliasesAliases.md)
 - [Luxsci::AliasesAliasAddressBody](docs/AliasesAliasAddressBody.md)
 - [Luxsci::AllOfinlineResponse20075Data](docs/AllOfinlineResponse20075Data.md)
 - [Luxsci::AnyOfinlineResponse20070DataRow](docs/AnyOfinlineResponse20070DataRow.md)
 - [Luxsci::ApppasswordSuffixBody](docs/ApppasswordSuffixBody.md)
 - [Luxsci::AuthBody](docs/AuthBody.md)
 - [Luxsci::Campaign](docs/Campaign.md)
 - [Luxsci::Contact](docs/Contact.md)
 - [Luxsci::ContentLibraryFilePathBody](docs/ContentLibraryFilePathBody.md)
 - [Luxsci::ContentLibraryMeta](docs/ContentLibraryMeta.md)
 - [Luxsci::ContentTag](docs/ContentTag.md)
 - [Luxsci::DkimReport](docs/DkimReport.md)
 - [Luxsci::DomainReport](docs/DomainReport.md)
 - [Luxsci::DomainsDomainNameBody](docs/DomainsDomainNameBody.md)
 - [Luxsci::EmailArBody](docs/EmailArBody.md)
 - [Luxsci::EmailForwardingBody](docs/EmailForwardingBody.md)
 - [Luxsci::EmailSendBody](docs/EmailSendBody.md)
 - [Luxsci::EmailSendBody1](docs/EmailSendBody1.md)
 - [Luxsci::EntriesDeleteBody](docs/EntriesDeleteBody.md)
 - [Luxsci::EntriesImportBody](docs/EntriesImportBody.md)
 - [Luxsci::InlineResponse200](docs/InlineResponse200.md)
 - [Luxsci::InlineResponse2001](docs/InlineResponse2001.md)
 - [Luxsci::InlineResponse20010](docs/InlineResponse20010.md)
 - [Luxsci::InlineResponse20010Data](docs/InlineResponse20010Data.md)
 - [Luxsci::InlineResponse20011](docs/InlineResponse20011.md)
 - [Luxsci::InlineResponse20011Data](docs/InlineResponse20011Data.md)
 - [Luxsci::InlineResponse20012](docs/InlineResponse20012.md)
 - [Luxsci::InlineResponse20013](docs/InlineResponse20013.md)
 - [Luxsci::InlineResponse20013Data](docs/InlineResponse20013Data.md)
 - [Luxsci::InlineResponse20014](docs/InlineResponse20014.md)
 - [Luxsci::InlineResponse20014Data](docs/InlineResponse20014Data.md)
 - [Luxsci::InlineResponse20015](docs/InlineResponse20015.md)
 - [Luxsci::InlineResponse20015Data](docs/InlineResponse20015Data.md)
 - [Luxsci::InlineResponse20016](docs/InlineResponse20016.md)
 - [Luxsci::InlineResponse20016Data](docs/InlineResponse20016Data.md)
 - [Luxsci::InlineResponse20017](docs/InlineResponse20017.md)
 - [Luxsci::InlineResponse20017Data](docs/InlineResponse20017Data.md)
 - [Luxsci::InlineResponse20018](docs/InlineResponse20018.md)
 - [Luxsci::InlineResponse20018Data](docs/InlineResponse20018Data.md)
 - [Luxsci::InlineResponse20019](docs/InlineResponse20019.md)
 - [Luxsci::InlineResponse20019Data](docs/InlineResponse20019Data.md)
 - [Luxsci::InlineResponse2001Data](docs/InlineResponse2001Data.md)
 - [Luxsci::InlineResponse2002](docs/InlineResponse2002.md)
 - [Luxsci::InlineResponse20020](docs/InlineResponse20020.md)
 - [Luxsci::InlineResponse20020Data](docs/InlineResponse20020Data.md)
 - [Luxsci::InlineResponse20021](docs/InlineResponse20021.md)
 - [Luxsci::InlineResponse20022](docs/InlineResponse20022.md)
 - [Luxsci::InlineResponse20023](docs/InlineResponse20023.md)
 - [Luxsci::InlineResponse20023Data](docs/InlineResponse20023Data.md)
 - [Luxsci::InlineResponse20024](docs/InlineResponse20024.md)
 - [Luxsci::InlineResponse20024Data](docs/InlineResponse20024Data.md)
 - [Luxsci::InlineResponse20025](docs/InlineResponse20025.md)
 - [Luxsci::InlineResponse20025Data](docs/InlineResponse20025Data.md)
 - [Luxsci::InlineResponse20026](docs/InlineResponse20026.md)
 - [Luxsci::InlineResponse20026Data](docs/InlineResponse20026Data.md)
 - [Luxsci::InlineResponse20027](docs/InlineResponse20027.md)
 - [Luxsci::InlineResponse20027Data](docs/InlineResponse20027Data.md)
 - [Luxsci::InlineResponse20028](docs/InlineResponse20028.md)
 - [Luxsci::InlineResponse20028Data](docs/InlineResponse20028Data.md)
 - [Luxsci::InlineResponse20029](docs/InlineResponse20029.md)
 - [Luxsci::InlineResponse20029Data](docs/InlineResponse20029Data.md)
 - [Luxsci::InlineResponse2002Data](docs/InlineResponse2002Data.md)
 - [Luxsci::InlineResponse2003](docs/InlineResponse2003.md)
 - [Luxsci::InlineResponse20030](docs/InlineResponse20030.md)
 - [Luxsci::InlineResponse20030Data](docs/InlineResponse20030Data.md)
 - [Luxsci::InlineResponse20031](docs/InlineResponse20031.md)
 - [Luxsci::InlineResponse20031Data](docs/InlineResponse20031Data.md)
 - [Luxsci::InlineResponse20032](docs/InlineResponse20032.md)
 - [Luxsci::InlineResponse20032Data](docs/InlineResponse20032Data.md)
 - [Luxsci::InlineResponse20033](docs/InlineResponse20033.md)
 - [Luxsci::InlineResponse20034](docs/InlineResponse20034.md)
 - [Luxsci::InlineResponse20035](docs/InlineResponse20035.md)
 - [Luxsci::InlineResponse20035Data](docs/InlineResponse20035Data.md)
 - [Luxsci::InlineResponse20036](docs/InlineResponse20036.md)
 - [Luxsci::InlineResponse20037](docs/InlineResponse20037.md)
 - [Luxsci::InlineResponse20037Data](docs/InlineResponse20037Data.md)
 - [Luxsci::InlineResponse20038](docs/InlineResponse20038.md)
 - [Luxsci::InlineResponse20038Data](docs/InlineResponse20038Data.md)
 - [Luxsci::InlineResponse20039](docs/InlineResponse20039.md)
 - [Luxsci::InlineResponse20039Data](docs/InlineResponse20039Data.md)
 - [Luxsci::InlineResponse20039DataContacts](docs/InlineResponse20039DataContacts.md)
 - [Luxsci::InlineResponse2004](docs/InlineResponse2004.md)
 - [Luxsci::InlineResponse20040](docs/InlineResponse20040.md)
 - [Luxsci::InlineResponse20040Data](docs/InlineResponse20040Data.md)
 - [Luxsci::InlineResponse20041](docs/InlineResponse20041.md)
 - [Luxsci::InlineResponse20042](docs/InlineResponse20042.md)
 - [Luxsci::InlineResponse20042Data](docs/InlineResponse20042Data.md)
 - [Luxsci::InlineResponse20043](docs/InlineResponse20043.md)
 - [Luxsci::InlineResponse20044](docs/InlineResponse20044.md)
 - [Luxsci::InlineResponse20044Data](docs/InlineResponse20044Data.md)
 - [Luxsci::InlineResponse20045](docs/InlineResponse20045.md)
 - [Luxsci::InlineResponse20045Data](docs/InlineResponse20045Data.md)
 - [Luxsci::InlineResponse20046](docs/InlineResponse20046.md)
 - [Luxsci::InlineResponse20047](docs/InlineResponse20047.md)
 - [Luxsci::InlineResponse20048](docs/InlineResponse20048.md)
 - [Luxsci::InlineResponse20048Data](docs/InlineResponse20048Data.md)
 - [Luxsci::InlineResponse20049](docs/InlineResponse20049.md)
 - [Luxsci::InlineResponse2004Data](docs/InlineResponse2004Data.md)
 - [Luxsci::InlineResponse2005](docs/InlineResponse2005.md)
 - [Luxsci::InlineResponse20050](docs/InlineResponse20050.md)
 - [Luxsci::InlineResponse20051](docs/InlineResponse20051.md)
 - [Luxsci::InlineResponse20052](docs/InlineResponse20052.md)
 - [Luxsci::InlineResponse20053](docs/InlineResponse20053.md)
 - [Luxsci::InlineResponse20053Data](docs/InlineResponse20053Data.md)
 - [Luxsci::InlineResponse20054](docs/InlineResponse20054.md)
 - [Luxsci::InlineResponse20054Data](docs/InlineResponse20054Data.md)
 - [Luxsci::InlineResponse20055](docs/InlineResponse20055.md)
 - [Luxsci::InlineResponse20056](docs/InlineResponse20056.md)
 - [Luxsci::InlineResponse20056Data](docs/InlineResponse20056Data.md)
 - [Luxsci::InlineResponse20057](docs/InlineResponse20057.md)
 - [Luxsci::InlineResponse20057Data](docs/InlineResponse20057Data.md)
 - [Luxsci::InlineResponse20058](docs/InlineResponse20058.md)
 - [Luxsci::InlineResponse20059](docs/InlineResponse20059.md)
 - [Luxsci::InlineResponse20059Data](docs/InlineResponse20059Data.md)
 - [Luxsci::InlineResponse2006](docs/InlineResponse2006.md)
 - [Luxsci::InlineResponse20060](docs/InlineResponse20060.md)
 - [Luxsci::InlineResponse20061](docs/InlineResponse20061.md)
 - [Luxsci::InlineResponse20062](docs/InlineResponse20062.md)
 - [Luxsci::InlineResponse20063](docs/InlineResponse20063.md)
 - [Luxsci::InlineResponse20064](docs/InlineResponse20064.md)
 - [Luxsci::InlineResponse20064Data](docs/InlineResponse20064Data.md)
 - [Luxsci::InlineResponse20065](docs/InlineResponse20065.md)
 - [Luxsci::InlineResponse20066](docs/InlineResponse20066.md)
 - [Luxsci::InlineResponse20067](docs/InlineResponse20067.md)
 - [Luxsci::InlineResponse20068](docs/InlineResponse20068.md)
 - [Luxsci::InlineResponse20068Data](docs/InlineResponse20068Data.md)
 - [Luxsci::InlineResponse20069](docs/InlineResponse20069.md)
 - [Luxsci::InlineResponse20069Data](docs/InlineResponse20069Data.md)
 - [Luxsci::InlineResponse2006Data](docs/InlineResponse2006Data.md)
 - [Luxsci::InlineResponse2007](docs/InlineResponse2007.md)
 - [Luxsci::InlineResponse20070](docs/InlineResponse20070.md)
 - [Luxsci::InlineResponse20070Data](docs/InlineResponse20070Data.md)
 - [Luxsci::InlineResponse20071](docs/InlineResponse20071.md)
 - [Luxsci::InlineResponse20071Data](docs/InlineResponse20071Data.md)
 - [Luxsci::InlineResponse20072](docs/InlineResponse20072.md)
 - [Luxsci::InlineResponse20072Data](docs/InlineResponse20072Data.md)
 - [Luxsci::InlineResponse20073](docs/InlineResponse20073.md)
 - [Luxsci::InlineResponse20073Data](docs/InlineResponse20073Data.md)
 - [Luxsci::InlineResponse20074](docs/InlineResponse20074.md)
 - [Luxsci::InlineResponse20075](docs/InlineResponse20075.md)
 - [Luxsci::InlineResponse2007Data](docs/InlineResponse2007Data.md)
 - [Luxsci::InlineResponse2008](docs/InlineResponse2008.md)
 - [Luxsci::InlineResponse2008Data](docs/InlineResponse2008Data.md)
 - [Luxsci::InlineResponse2009](docs/InlineResponse2009.md)
 - [Luxsci::InlineResponse2009Data](docs/InlineResponse2009Data.md)
 - [Luxsci::InlineResponse201](docs/InlineResponse201.md)
 - [Luxsci::InlineResponse2011](docs/InlineResponse2011.md)
 - [Luxsci::InlineResponse2011Data](docs/InlineResponse2011Data.md)
 - [Luxsci::ListGroupListGroupIdBody](docs/ListGroupListGroupIdBody.md)
 - [Luxsci::ListGroupListGroupIdBody1](docs/ListGroupListGroupIdBody1.md)
 - [Luxsci::MarketingAddCampaignBody](docs/MarketingAddCampaignBody.md)
 - [Luxsci::MarketingAddContactBody](docs/MarketingAddContactBody.md)
 - [Luxsci::MarketingAddContactsBody](docs/MarketingAddContactsBody.md)
 - [Luxsci::MarketingAddListBody](docs/MarketingAddListBody.md)
 - [Luxsci::MarketingCampaignScheduleBody](docs/MarketingCampaignScheduleBody.md)
 - [Luxsci::MarketingSuppressBody](docs/MarketingSuppressBody.md)
 - [Luxsci::Message](docs/Message.md)
 - [Luxsci::ModelAlias](docs/ModelAlias.md)
 - [Luxsci::OneOfReportResponseRowsItems](docs/OneOfReportResponseRowsItems.md)
 - [Luxsci::ReportResponse](docs/ReportResponse.md)
 - [Luxsci::SM3CSVResponse](docs/SM3CSVResponse.md)
 - [Luxsci::SM3Campaign](docs/SM3Campaign.md)
 - [Luxsci::SM3CampaignPOSTBody](docs/SM3CampaignPOSTBody.md)
 - [Luxsci::SM3CampaignPUTBody](docs/SM3CampaignPUTBody.md)
 - [Luxsci::SM3Contact](docs/SM3Contact.md)
 - [Luxsci::SM3ContactPOSTBody](docs/SM3ContactPOSTBody.md)
 - [Luxsci::SM3ContactPOSTBodyDerived](docs/SM3ContactPOSTBodyDerived.md)
 - [Luxsci::SM3ContactPUTBody](docs/SM3ContactPUTBody.md)
 - [Luxsci::SM3CustomField](docs/SM3CustomField.md)
 - [Luxsci::SM3List](docs/SM3List.md)
 - [Luxsci::SM3ListBase](docs/SM3ListBase.md)
 - [Luxsci::SM3ListBody](docs/SM3ListBody.md)
 - [Luxsci::SecureForm](docs/SecureForm.md)
 - [Luxsci::SecureFormDbRow](docs/SecureFormDbRow.md)
 - [Luxsci::SecureFormDbRowFiles_](docs/SecureFormDbRowFiles_.md)
 - [Luxsci::SecurelineRecipientsBody](docs/SecurelineRecipientsBody.md)
 - [Luxsci::SecurelineSendBody](docs/SecurelineSendBody.md)
 - [Luxsci::Server](docs/Server.md)
 - [Luxsci::ServerIdSendingRateBody](docs/ServerIdSendingRateBody.md)
 - [Luxsci::StringOrNumber](docs/StringOrNumber.md)
 - [Luxsci::Suppression](docs/Suppression.md)
 - [Luxsci::Template](docs/Template.md)
 - [Luxsci::TemplateGroupTemplateGroupIdBody](docs/TemplateGroupTemplateGroupIdBody.md)
 - [Luxsci::TemplateGroupTemplateGroupIdBody1](docs/TemplateGroupTemplateGroupIdBody1.md)
 - [Luxsci::UpdateCampaignIdBody](docs/UpdateCampaignIdBody.md)
 - [Luxsci::UpdateContactEmailBody](docs/UpdateContactEmailBody.md)
 - [Luxsci::UpdateContactRequestBody](docs/UpdateContactRequestBody.md)
 - [Luxsci::UpdateListIdBody](docs/UpdateListIdBody.md)
 - [Luxsci::UserUsernameBody](docs/UserUsernameBody.md)
 - [Luxsci::UsernameFieldsBody](docs/UsernameFieldsBody.md)
 - [Luxsci::UsernamePasswordBody](docs/UsernamePasswordBody.md)
 - [Luxsci::UsernamePasswordBody1](docs/UsernamePasswordBody1.md)
 - [Luxsci::UsernameProfileBody](docs/UsernameProfileBody.md)
 - [Luxsci::UsernameRenameBody](docs/UsernameRenameBody.md)
 - [Luxsci::UsersUsernameBody](docs/UsersUsernameBody.md)
 - [Luxsci::UsersUsernameBody1](docs/UsersUsernameBody1.md)
 - [Luxsci::UserusernameemailsendJson](docs/UserusernameemailsendJson.md)
 - [Luxsci::UserusernameemailsendJsonMessage](docs/UserusernameemailsendJsonMessage.md)
 - [Luxsci::UserusernameemailsendJsonMessages](docs/UserusernameemailsendJsonMessages.md)
 - [Luxsci::WebAide](docs/WebAide.md)
 - [Luxsci::WebaideIdEntryIdBody](docs/WebaideIdEntryIdBody.md)
 - [Luxsci::WebaideTypeWebaideIdBody](docs/WebaideTypeWebaideIdBody.md)
 - [Luxsci::WebaidesWebaideTypeBody](docs/WebaidesWebaideTypeBody.md)

